# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Florida."""


ACACIA_VILLAS_CDP = "00075"
ALACHUA_CITY = "00375"
ALAFAYA_CDP = "00410"
ALFORD_TOWN = "00625"
ALLENTOWN_CDP = "00800"
ALTAMONTE_SPRINGS_CITY = "00950"
ALTHA_TOWN = "01000"
ALTOONA_CDP = "01050"
ALTURAS_CDP = "01100"
ALVA_CDP = "01125"
ANDREWS_CDP = "01353"
ANNA_MARIA_CITY = "01475"
APALACHICOLA_CITY = "01625"
APOLLO_BEACH_CDP = "01675"
APOPKA_CITY = "01700"
ARCADIA_CITY = "01750"
ARCHER_CITY = "01775"
ARIPEKA_CDP = "01875"
ASBURY_LAKE_CDP = "02187"
ASTATULA_TOWN = "02250"
ASTOR_CDP = "02275"
ATLANTIC_BEACH_CITY = "02400"
ATLANTIS_CITY = "02500"
AUBURNDALE_CITY = "02550"
AUCILLA_CDP = "02575"
AVALON_CDP = "02660"
AVE_MARIA_CDP = "02677"
AVENTURA_CITY = "02681"
AVON_PARK_CITY = "02750"
AZALEA_PARK_CDP = "02850"
BABSON_PARK_CDP = "02900"
BAGDAD_CDP = "02925"
BAL_HARBOUR_VILLAGE = "03275"
BALDWIN_TOWN = "03250"
BALM_CDP = "03375"
BARDMOOR_CDP = "03480"
BARTOW_CITY = "03675"
BASCOM_TOWN = "03725"
BAY_HARBOR_ISLANDS_TOWN = "03975"
BAY_HILL_CDP = "04070"
BAY_LAKE_CITY = "04150"
BAY_PINES_CDP = "04200"
BAYONET_POINT_CDP = "04162"
BAYPORT_CDP = "04250"
BAYSHORE_GARDENS_CDP = "04350"
BEACON_SQUARE_CDP = "04650"
BEAR_CREEK_CDP = "04735"
BEE_RIDGE_CDP = "04925"
BELL_TOWN = "04975"
BELLAIR_MEADOWBROOK_TERRACE_CDP = "05025"
BELLE_GLADE_CITY = "05200"
BELLE_ISLE_CITY = "05300"
BELLEAIR_BEACH_CITY = "05100"
BELLEAIR_BLUFFS_CITY = "05125"
BELLEAIR_SHORE_TOWN = "05150"
BELLEAIR_TOWN = "05075"
BELLEVIEW_CITY = "05375"
BELLVIEW_CDP = "05462"
BERKSHIRE_LAKES_CDP = "05806"
BERRYDALE_CDP = "05825"
BEVERLY_BEACH_TOWN = "06100"
BEVERLY_HILLS_CDP = "06125"
BIG_COPPITT_KEY_CDP = "06350"
BIG_PINE_KEY_CDP = "06425"
BISCAYNE_PARK_VILLAGE = "06600"
BITHLO_CDP = "06625"
BLACK_DIAMOND_CDP = "06667"
BLACK_HAMMOCK_CDP = "06670"
BLOOMINGDALE_CDP = "06875"
BLOUNTSTOWN_CITY = "06925"
BOCA_RATON_CITY = "07300"
BOKEELIA_CDP = "07375"
BONIFAY_CITY = "07450"
BONITA_SPRINGS_CITY = "07525"
BOULEVARD_GARDENS_CDP = "07687"
BOWLING_GREEN_CITY = "07775"
BOYNTON_BEACH_CITY = "07875"
BRADENTON_BEACH_CITY = "07975"
BRADENTON_CITY = "07950"
BRADFORDVILLE_CDP = "08075"
BRADLEY_JUNCTION_CDP = "08125"
BRANDON_CDP = "08150"
BRANFORD_TOWN = "08175"
BRENT_CDP = "08300"
BRINY_BREEZES_TOWN = "08575"
BRISTOL_CITY = "08600"
BROADVIEW_PARK_CDP = "08650"
BRONSON_TOWN = "08700"
BROOKER_TOWN = "08725"
BROOKRIDGE_CDP = "08762"
BROOKSVILLE_CITY = "08800"
BROWNSDALE_CDP = "08925"
BROWNSVILLE_CDP = "09000"
BUCKHEAD_RIDGE_CDP = "09315"
BUCKINGHAM_CDP = "09350"
BUENAVENTURA_LAKES_CDP = "09415"
BUNNELL_CITY = "09550"
BURNT_STORE_MARINA_CDP = "09612"
BUSHNELL_CITY = "09625"
BUTLER_BEACH_CDP = "09630"
CABANA_COLONY_CDP = "09655"
CALLAHAN_TOWN = "09700"
CALLAWAY_CITY = "09725"
CAMPBELL_CDP = "09875"
CAMPBELLTON_TOWN = "09900"
CANAL_POINT_CDP = "10100"
CAPE_CANAVERAL_CITY = "10250"
CAPE_CORAL_CITY = "10275"
CAPITOLA_CDP = "10350"
CAPTIVA_CDP = "10425"
CARRABELLE_CITY = "10725"
CARROLLWOOD_CDP = "10825"
CARYVILLE_TOWN = "10975"
CASSELBERRY_CITY = "11050"
CEDAR_GROVE_CDP = "11150"
CEDAR_KEY_CITY = "11225"
CELEBRATION_CDP = "11285"
CENTER_HILL_CITY = "11325"
CENTURY_TOWN = "11362"
CHAIRES_CDP = "11525"
CHARLESTON_PARK_CDP = "11597"
CHARLOTTE_HARBOR_CDP = "11625"
CHARLOTTE_PARK_CDP = "11650"
CHATTAHOOCHEE_CITY = "11800"
CHEVAL_CDP = "11912"
CHIEFLAND_CITY = "11925"
CHIPLEY_CITY = "11975"
CHOKOLOSKEE_CDP = "12150"
CHRISTMAS_CDP = "12250"
CHULUOTA_CDP = "12275"
CHUMUCKLA_CDP = "12300"
CINCO_BAYOU_TOWN = "12325"
CITRUS_HILLS_CDP = "12412"
CITRUS_PARK_CDP = "12425"
CITRUS_SPRINGS_CDP = "12450"
CLARCONA_CDP = "12675"
CLEARWATER_CITY = "12875"
CLERMONT_CITY = "12925"
CLEVELAND_CDP = "12950"
CLEWISTON_CITY = "13000"
CLOUD_LAKE_TOWN = "13050"
COBBTOWN_CDP = "13125"
COCOA_BEACH_CITY = "13175"
COCOA_WEST_CDP = "13225"
COCOA_CITY = "13150"
COCONUT_CREEK_CITY = "13275"
COLEMAN_CITY = "13400"
COMBEE_SETTLEMENT_CDP = "13775"
CONNERTON_CDP = "13965"
CONWAY_CDP = "14050"
COOPER_CITY_CITY = "14125"
CORAL_GABLES_CITY = "14250"
CORAL_SPRINGS_CITY = "14400"
CORAL_TERRACE_CDP = "14412"
CORTEZ_CDP = "14700"
COTTONDALE_TOWN = "14850"
COUNTRY_CLUB_CDP = "14895"
COUNTRY_WALK_CDP = "15055"
CRAWFORDVILLE_CDP = "15300"
CRESCENT_BEACH_CDP = "15325"
CRESCENT_CITY_CITY = "15375"
CRESTVIEW_CITY = "15475"
CROOKED_LAKE_PARK_CDP = "15515"
CROSS_CITY_TOWN = "15575"
CRYSTAL_LAKE_CDP = "15725"
CRYSTAL_RIVER_CITY = "15775"
CRYSTAL_SPRINGS_CDP = "15800"
CUDJOE_KEY_CDP = "15862"
CUTLER_BAY_TOWN = "15968"
CYPRESS_GARDENS_CDP = "16050"
CYPRESS_LAKE_CDP = "16062"
CYPRESS_QUARTERS_CDP = "16100"
DADE_CITY_NORTH_CDP = "16175"
DADE_CITY_CITY = "16125"
DANIA_BEACH_CITY = "16335"
DAVENPORT_CITY = "16450"
DAVIE_TOWN = "16475"
DAY_CDP = "16500"
DAYTONA_BEACH_SHORES_CITY = "16550"
DAYTONA_BEACH_CITY = "16525"
DE_LEON_SPRINGS_CDP = "16975"
DEBARY_CITY = "16675"
DEFUNIAK_SPRINGS_CITY = "16800"
DELAND_SOUTHWEST_CDP = "16937"
DELAND_CITY = "16875"
DEERFIELD_BEACH_CITY = "16725"
DELRAY_BEACH_CITY = "17100"
DELTONA_CITY = "17200"
DESOTO_ACRES_CDP = "17273"
DESOTO_LAKES_CDP = "17300"
DESTIN_CITY = "17325"
DICKERSON_CITY_CDP = "17450"
DIXONVILLE_CDP = "17710"
DOCTOR_PHILLIPS_CDP = "17725"
DORAL_CITY = "17935"
DOVER_CDP = "18075"
DUCK_KEY_CDP = "18425"
DUNDEE_TOWN = "18550"
DUNEDIN_CITY = "18575"
DUNNELLON_CITY = "18675"
EAGLE_LAKE_CITY = "18875"
EAST_BRONSON_CDP = "19025"
EAST_LAKE_CDP = "19206"
EAST_LAKE_ORIENT_PARK_CDP = "19212"
EAST_MILTON_CDP = "19275"
EAST_PALATKA_CDP = "19350"
EAST_WILLISTON_CDP = "19575"
EASTPOINT_CDP = "19400"
EATONVILLE_TOWN = "19650"
EBRO_TOWN = "19725"
EDGEWATER_CITY = "19825"
EDGEWOOD_CITY = "19900"
EGLIN_AFB_CDP = "20050"
EGYPT_LAKE_LETO_CDP = "20108"
EL_PORTAL_VILLAGE = "20650"
ELFERS_CDP = "20275"
ELLENTON_CDP = "20375"
ENGLEWOOD_CDP = "20825"
ENSLEY_CDP = "20925"
ESTERO_VILLAGE = "21150"
ESTO_TOWN = "21250"
EUSTIS_CITY = "21350"
EVERGLADES_CITY = "21425"
FAIRVIEW_SHORES_CDP = "21750"
FANNING_SPRINGS_CITY = "21850"
FEATHER_SOUND_CDP = "21945"
FELLSMERE_CITY = "22100"
FERN_PARK_CDP = "22250"
FERNANDINA_BEACH_CITY = "22175"
FERNDALE_CDP = "22225"
FERRY_PASS_CDP = "22275"
FIDELIS_CDP = "22325"
FISH_HAWK_CDP = "22387"
FISHER_ISLAND_CDP = "22375"
FIVE_POINTS_CDP = "22475"
FLAGLER_BEACH_CITY = "22550"
FLAGLER_ESTATES_CDP = "22560"
FLEMING_ISLAND_CDP = "22660"
FLORAL_CITY_CDP = "22775"
FLORIDA_CITY_CITY = "22975"
FLORIDA_GULF_COAST_UNIVERSITY_CDP = "23005"
FLORIDA_RIDGE_CDP = "23050"
FLORIDATOWN_CDP = "23125"
FOREST_CITY_CDP = "23375"
FORT_BRADEN_CDP = "23680"
FORT_DENAUD_CDP = "23730"
FORT_GREEN_CDP = "23850"
FORT_GREEN_SPRINGS_CDP = "23875"
FORT_LAUDERDALE_CITY = "24000"
FORT_MEADE_CITY = "24100"
FORT_MYERS_BEACH_TOWN = "24150"
FORT_MYERS_SHORES_CDP = "24175"
FORT_MYERS_CITY = "24125"
FORT_PIERCE_NORTH_CDP = "24337"
FORT_PIERCE_SOUTH_CDP = "24387"
FORT_PIERCE_CITY = "24300"
FORT_WALTON_BEACH_CITY = "24475"
FORT_WHITE_TOWN = "24500"
FOUNTAINEBLEAU_CDP = "24562"
FOUR_CORNERS_CDP = "24581"
FRANKLIN_PARK_CDP = "24710"
FREEPORT_CITY = "24825"
FROSTPROOF_CITY = "24900"
FRUIT_COVE_CDP = "24925"
FRUITLAND_PARK_CITY = "24975"
FRUITVILLE_CDP = "25000"
FULLER_HEIGHTS_CDP = "25025"
FUSSELS_CORNER_CDP = "25125"
GAINESVILLE_CITY = "25175"
GARCON_POINT_CDP = "25392"
GARDEN_GROVE_CDP = "25475"
GARDNER_CDP = "25550"
GATEWAY_CDP = "25655"
GENEVA_CDP = "25750"
GIBSONTON_CDP = "25900"
GIFFORD_CDP = "25925"
GLADEVIEW_CDP = "25987"
GLEN_RIDGE_TOWN = "26050"
GLEN_ST_MARY_TOWN = "26075"
GLENCOE_CDP = "26000"
GLENVAR_HEIGHTS_CDP = "26100"
GOLDEN_BEACH_TOWN = "26250"
GOLDEN_GATE_CDP = "26300"
GOLDEN_GLADES_CDP = "26375"
GOLDENROD_CDP = "26475"
GOLF_VILLAGE = "26550"
GONZALEZ_CDP = "26700"
GOODLAND_CDP = "26775"
GOTHA_CDP = "26900"
GOULDING_CDP = "26925"
GOULDS_CDP = "26950"
GRACEVILLE_CITY = "27000"
GRAND_RIDGE_TOWN = "27175"
GRANT_VALKARIA_TOWN = "27256"
GREEN_COVE_SPRINGS_CITY = "27400"
GREENACRES_CITY = "27322"
GREENBRIAR_CDP = "27360"
GREENSBORO_TOWN = "27550"
GREENVILLE_TOWN = "27575"
GREENWOOD_TOWN = "27600"
GRENELEFE_CDP = "27635"
GRETNA_CITY = "27650"
GROVE_CITY_CDP = "27775"
GROVELAND_CITY = "27800"
GULF_BREEZE_CITY = "28000"
GULF_GATE_CDP = "28045"
GULF_STREAM_TOWN = "28275"
GULFPORT_CITY = "28175"
GUN_CLUB_ESTATES_CDP = "28305"
HAINES_CITY_CITY = "28400"
HALLANDALE_BEACH_CITY = "28452"
HAMPTON_CITY = "28575"
HARBOR_BLUFFS_CDP = "28650"
HARBOUR_HEIGHTS_CDP = "28800"
HARLEM_CDP = "28925"
HARLEM_HEIGHTS_CDP = "28937"
HAROLD_CDP = "29000"
HASTINGS_CDP = "29100"
HAVANA_TOWN = "29150"
HAVERHILL_TOWN = "29200"
HAWTHORNE_CITY = "29275"
HEATHROW_CDP = "29320"
HERITAGE_BAY_CDP = "29381"
HERITAGE_PINES_CDP = "29385"
HERNANDO_BEACH_CDP = "29437"
HERNANDO_CDP = "29425"
HIALEAH_GARDENS_CITY = "30025"
HIALEAH_CITY = "30000"
HIGH_POINT_CDP = "30494"
HIGH_SPRINGS_CITY = "30525"
HIGHLAND_BEACH_TOWN = "30200"
HIGHLAND_CITY_CDP = "30225"
HIGHLAND_PARK_VILLAGE = "30325"
HILL_N_DALE_CDP = "30800"
HILLCREST_HEIGHTS_TOWN = "30700"
HILLIARD_TOWN = "30750"
HILLSBORO_BEACH_TOWN = "30850"
HILLSBORO_PINES_CDP = "30858"
HOBE_SOUND_CDP = "30975"
HOLDEN_HEIGHTS_CDP = "31025"
HOLDEN_LAKES_CDP = "31030"
HOLIDAY_CDP = "31075"
HOLLEY_CDP = "31275"
HOLLY_HILL_CITY = "31350"
HOLLYWOOD_CITY = "32000"
HOLMES_BEACH_CITY = "32150"
HOMELAND_CDP = "32250"
HOMESTEAD_BASE_CDP = "32325"
HOMESTEAD_CITY = "32275"
HOMOSASSA_CDP = "32375"
HOMOSASSA_SPRINGS_CDP = "32400"
HORIZON_WEST_CDP = "32610"
HORSESHOE_BEACH_TOWN = "32650"
HOSFORD_CDP = "32675"
HOWEY_IN_THE_HILLS_TOWN = "32775"
HUDSON_CDP = "32825"
HUNTERS_CREEK_CDP = "32967"
HURLBURT_FIELD_CDP = "32975"
HUTCHINSON_ISLAND_SOUTH_CDP = "32993"
HYPOLUXO_TOWN = "33150"
IMMOKALEE_CDP = "33250"
INDIALANTIC_TOWN = "33375"
INDIAN_CREEK_VILLAGE = "33425"
INDIAN_HARBOUR_BEACH_CITY = "33450"
INDIAN_LAKE_ESTATES_CDP = "33500"
INDIAN_RIVER_ESTATES_CDP = "33585"
INDIAN_RIVER_SHORES_TOWN = "33600"
INDIAN_ROCKS_BEACH_CITY = "33625"
INDIAN_SHORES_TOWN = "33675"
INDIANTOWN_VILLAGE = "33700"
INGLIS_TOWN = "33800"
INTERLACHEN_TOWN = "33900"
INVERNESS_HIGHLANDS_NORTH_CDP = "33958"
INVERNESS_HIGHLANDS_SOUTH_CDP = "33966"
INVERNESS_CITY = "33950"
INWOOD_CDP = "34000"
IONA_CDP = "34012"
ISLAMORADA = "34132"
ISLAND_WALK_CDP = "34185"
ISTACHATTA_CDP = "34275"
IVES_ESTATES_CDP = "34400"
JACKSONVILLE_BEACH_CITY = "35050"
JACKSONVILLE_CITY = "35000"
JACOB_CITY_CITY = "35200"
JAN_PHYL_VILLAGE_CDP = "35300"
JASMINE_ESTATES_CDP = "35350"
JASPER_CITY = "35375"
JAY_TOWN = "35425"
JENNINGS_TOWN = "35525"
JENSEN_BEACH_CDP = "35550"
JUNE_PARK_CDP = "35800"
JUNO_BEACH_TOWN = "35850"
JUNO_RIDGE_CDP = "35862"
JUPITER_FARMS_CDP = "35890"
JUPITER_INLET_COLONY_TOWN = "35900"
JUPITER_ISLAND_TOWN = "35925"
JUPITER_TOWN = "35875"
KATHLEEN_CDP = "35950"
KENDALE_LAKES_CDP = "36062"
KENDALL_CDP = "36100"
KENDALL_WEST_CDP = "36121"
KENNETH_CITY_TOWN = "36175"
KENSINGTON_PARK_CDP = "36200"
KENWOOD_ESTATES_CDP = "36220"
KEY_BISCAYNE_VILLAGE = "36300"
KEY_COLONY_BEACH_CITY = "36325"
KEY_LARGO_CDP = "36375"
KEY_VISTA_CDP = "36535"
KEY_WEST_CITY = "36550"
KEYSTONE_CDP = "36462"
KEYSTONE_HEIGHTS_CITY = "36475"
KISSIMMEE_CITY = "36950"
LA_CROSSE_TOWN = "37300"
LABELLE_CITY = "37225"
LACOOCHEE_CDP = "37275"
LADY_LAKE_TOWN = "37375"
LAGUNA_BEACH_CDP = "37500"
LAKE_ALFRED_CITY = "37525"
LAKE_BELVEDERE_ESTATES_CDP = "37542"
LAKE_BUENA_VISTA_CITY = "37625"
LAKE_BUTLER_CDP = "37648"
LAKE_BUTLER_CITY = "37650"
LAKE_CITY_CITY = "37775"
LAKE_CLARKE_SHORES_TOWN = "37800"
LAKE_HAMILTON_TOWN = "37975"
LAKE_HARBOR_CDP = "38000"
LAKE_HART_CDP = "38012"
LAKE_HELEN_CITY = "38025"
LAKE_KATHRYN_CDP = "38162"
LAKE_KERR_CDP = "38238"
LAKE_LINDSEY_CDP = "38275"
LAKE_LORRAINE_CDP = "38287"
LAKE_MACK_FOREST_HILLS_CDP = "38332"
LAKE_MAGDALENE_CDP = "38350"
LAKE_MARY_JANE_CDP = "38430"
LAKE_MARY_CITY = "38425"
LAKE_MYSTIC_CDP = "38519"
LAKE_PANASOFFKEE_CDP = "38575"
LAKE_PARK_TOWN = "38600"
LAKE_PLACID_TOWN = "38625"
LAKE_SARASOTA_CDP = "38690"
LAKE_WALES_CITY = "38950"
LAKE_WORTH_BEACH_CITY = "39081"
LAKELAND_HIGHLANDS_CDP = "38262"
LAKELAND_CITY = "38250"
LAKESIDE_CDP = "38813"
LAKEWOOD_PARK_CDP = "39062"
LAKEWOOD_RANCH_CDP = "39067"
LAMONT_CDP = "39100"
LAND_O_LAKES_CDP = "39200"
LANTANA_TOWN = "39375"
LARGO_CITY = "39425"
LAUDERDALE_LAKES_CITY = "39525"
LAUDERDALE_BY_THE_SEA_TOWN = "39475"
LAUDERHILL_CITY = "39550"
LAUREL_CDP = "39600"
LAUREL_HILL_CITY = "39650"
LAWTEY_CITY = "39700"
LAYTON_CITY = "39725"
LAZY_LAKE_VILLAGE = "39750"
LEALMAN_CDP = "39775"
LECANTO_CDP = "39825"
LEE_TOWN = "39850"
LEESBURG_CITY = "39875"
LEHIGH_ACRES_CDP = "39925"
LEISURE_CITY_CDP = "39950"
LELY_CDP = "39987"
LELY_RESORT_CDP = "40037"
LEMON_GROVE_CDP = "40100"
LIBERTY_TRIANGLE_CDP = "40387"
LIGHTHOUSE_POINT_CITY = "40450"
LIMESTONE_CDP = "40525"
LIMESTONE_CREEK_CDP = "40562"
LISBON_CDP = "40750"
LIVE_OAK_CITY = "40875"
LLOYD_CDP = "40950"
LOCHMOOR_WATERWAY_ESTATES_CDP = "40985"
LOCKHART_CDP = "41025"
LONGBOAT_KEY_TOWN = "41150"
LONGWOOD_CITY = "41250"
LOUGHMAN_CDP = "41400"
LOWER_GRAND_LAGOON_CDP = "41562"
LOXAHATCHEE_GROVES_TOWN = "41577"
LUTZ_CDP = "41775"
LYNN_HAVEN_CITY = "41825"
MACCLENNY_CITY = "41950"
MADEIRA_BEACH_CITY = "42400"
MADISON_CITY = "42425"
MAITLAND_CITY = "42575"
MALABAR_TOWN = "42625"
MALONE_TOWN = "42650"
MANALAPAN_TOWN = "42700"
MANASOTA_KEY_CDP = "42750"
MANATEE_ROAD_CDP = "42787"
MANGO_CDP = "42850"
MANGONIA_PARK_TOWN = "42900"
MARATHON_CITY = "43000"
MARCO_ISLAND_CITY = "43083"
MARCO_SHORES_HAMMOCK_BAY_CDP = "43090"
MARGATE_CITY = "43125"
MARIANNA_CITY = "43175"
MARINELAND_TOWN = "43250"
MARION_OAKS_CDP = "43300"
MARY_ESTHER_CITY = "43375"
MASARYKTOWN_CDP = "43400"
MASCOTTE_CITY = "43425"
MATLACHA_CDP = "43475"
MATLACHA_ISLES_MATLACHA_SHORES_CDP = "43484"
MAYO_TOWN = "43575"
MCGREGOR_CDP = "42090"
MCINTOSH_TOWN = "42150"
MEADOW_OAKS_CDP = "43785"
MEADOW_WOODS_CDP = "43800"
MEDLEY_TOWN = "43900"
MEDULLA_CDP = "43925"
MELBOURNE_BEACH_TOWN = "44000"
MELBOURNE_VILLAGE_TOWN = "44075"
MELBOURNE_CITY = "43975"
MEMPHIS_CDP = "44175"
MERRITT_ISLAND_CDP = "44275"
MEXICO_BEACH_CITY = "44300"
MIAMI_BEACH_CITY = "45025"
MIAMI_GARDENS_CITY = "45060"
MIAMI_LAKES_TOWN = "45100"
MIAMI_SHORES_VILLAGE = "45175"
MIAMI_SPRINGS_CITY = "45200"
MIAMI_CITY = "45000"
MICANOPY_TOWN = "45225"
MICCO_CDP = "45275"
MICCOSUKEE_CDP = "45300"
MIDDLEBURG_CDP = "45350"
MIDWAY_CDP_SANTA_ROSA_COUNTY = "45465"
MIDWAY_CDP_SEMINOLE_COUNTY = "45475"
MIDWAY_CITY = "45425"
MILTON_CITY = "45750"
MIMS_CDP = "45775"
MINNEOLA_CITY = "45900"
MIRAMAR_BEACH_CDP = "46000"
MIRAMAR_CITY = "45975"
MOLINO_CDP = "46225"
MONTICELLO_CITY = "46500"
MONTURA_CDP = "46520"
MONTVERDE_TOWN = "46525"
MOON_LAKE_CDP = "46540"
MOORE_HAVEN_CITY = "46550"
MORRISTON_CDP = "46725"
MOUNT_CARMEL_CDP = "47000"
MOUNT_DORA_CITY = "47050"
MOUNT_PLYMOUTH_CDP = "47125"
MULAT_CDP = "47175"
MULBERRY_CITY = "47200"
MUNSON_CDP = "47300"
MYRTLE_GROVE_CDP = "47550"
NAPLES_MANOR_CDP = "47650"
NAPLES_PARK_CDP = "47675"
NAPLES_CITY = "47625"
NARANJA_CDP = "47700"
NASSAU_VILLAGE_RATLIFF_CDP = "47787"
NAVARRE_BEACH_CDP = "48055"
NAVARRE_CDP = "48050"
NEPTUNE_BEACH_CITY = "48100"
NEW_PORT_RICHEY_EAST_CDP = "48525"
NEW_PORT_RICHEY_CITY = "48500"
NEW_SMYRNA_BEACH_CITY = "48625"
NEWBERRY_CITY = "48200"
NICEVILLE_CITY = "48750"
NOBLETON_CDP = "48825"
NOCATEE_CDP = "48850"
NOKOMIS_CDP = "48875"
NOMA_TOWN = "48900"
NORTH_BAY_VILLAGE_CITY = "49225"
NORTH_BROOKSVILLE_CDP = "49237"
NORTH_DELAND_CDP = "49275"
NORTH_FORT_MYERS_CDP = "49350"
NORTH_KEY_LARGO_CDP = "49406"
NORTH_LAUDERDALE_CITY = "49425"
NORTH_MERRITT_ISLAND_CDP = "49435"
NORTH_MIAMI_BEACH_CITY = "49475"
NORTH_MIAMI_CITY = "49450"
NORTH_PALM_BEACH_VILLAGE = "49600"
NORTH_PORT_CITY = "49675"
NORTH_REDINGTON_BEACH_TOWN = "49725"
NORTH_RIVER_SHORES_CDP = "49750"
NORTH_SARASOTA_CDP = "49787"
NORTH_WEEKI_WACHEE_CDP = "49905"
NORTHDALE_CDP = "49260"
OAK_HILL_CITY = "50450"
OAK_RIDGE_CDP = "50638"
OAKLAND_PARK_CITY = "50575"
OAKLAND_TOWN = "50525"
OAKLEAF_PLANTATION_CDP = "50630"
OCALA_ESTATES_CDP = "50756"
OCALA_CITY = "50750"
OCEAN_BREEZE_TOWN = "50875"
OCEAN_CITY_CDP = "50925"
OCEAN_RIDGE_TOWN = "50950"
OCKLAWAHA_CDP = "51050"
OCOEE_CITY = "51075"
ODESSA_CDP = "51100"
OJUS_CDP = "51125"
OKAHUMPKA_CDP = "51150"
OKEECHOBEE_CITY = "51200"
OLD_MIAKKA_CDP = "51342"
OLDSMAR_CITY = "51350"
OLGA_CDP = "51400"
OLYMPIA_HEIGHTS_CDP = "51475"
ON_TOP_OF_THE_WORLD_CDP = "51587"
ONA_CDP = "51500"
OPA_LOCKA_CITY = "51650"
ORANGE_CITY_CITY = "51825"
ORANGE_PARK_TOWN = "52125"
ORANGETREE_CDP = "52162"
ORCHID_TOWN = "52175"
ORIOLE_BEACH_CDP = "52250"
ORLANDO_CITY = "53000"
ORLOVISTA_CDP = "53100"
ORMOND_BEACH_CITY = "53150"
ORMOND_BY_THE_SEA_CDP = "53200"
OSPREY_CDP = "53425"
OTTER_CREEK_TOWN = "53500"
OVIEDO_CITY = "53575"
PACE_CDP = "53725"
PAGE_PARK_CDP = "53775"
PAHOKEE_CITY = "53800"
PAISLEY_CDP = "53850"
PALATKA_CITY = "53875"
PALM_BAY_CITY = "54000"
PALM_BEACH_GARDENS_CITY = "54075"
PALM_BEACH_SHORES_TOWN = "54150"
PALM_BEACH_TOWN = "54025"
PALM_CITY_CDP = "54175"
PALM_COAST_CITY = "54200"
PALM_HARBOR_CDP = "54350"
PALM_RIVER_CLAIR_MEL_CDP = "54387"
PALM_SHORES_TOWN = "54425"
PALM_SPRINGS_NORTH_CDP = "54500"
PALM_SPRINGS_VILLAGE = "54450"
PALM_VALLEY_CDP = "54525"
PALMER_RANCH_CDP = "54238"
PALMETTO_BAY_VILLAGE = "54275"
PALMETTO_ESTATES_CDP = "54300"
PALMETTO_CITY = "54250"
PALMONA_PARK_CDP = "54357"
PANACEA_CDP = "54625"
PANAMA_CITY_BEACH_CITY = "54725"
PANAMA_CITY_CITY = "54700"
PARADISE_HEIGHTS_CDP = "54912"
PARKER_CITY = "55075"
PARKLAND_CITY = "55125"
PASADENA_HILLS_CDP = "55305"
PATRICK_AFB_CDP = "55375"
PAXTON_TOWN = "55475"
PEA_RIDGE_CDP = "55532"
PEBBLE_CREEK_CDP = "55540"
PELICAN_BAY_CDP = "55650"
PELICAN_MARSH_CDP = "55680"
PEMBROKE_PARK_TOWN = "55750"
PEMBROKE_PINES_CITY = "55775"
PENNEY_FARMS_TOWN = "55875"
PENSACOLA_STATION_CDP = "56004"
PENSACOLA_CITY = "55925"
PERRY_CITY = "56150"
PIERSON_TOWN = "56425"
PINE_AIR_CDP = "56475"
PINE_CASTLE_CDP = "56500"
PINE_HILLS_CDP = "56825"
PINE_ISLAND_CDP = "56840"
PINE_ISLAND_CENTER_CDP = "56850"
PINE_LAKES_CDP = "56865"
PINE_LEVEL_CDP = "56955"
PINE_MANOR_CDP = "57025"
PINE_RIDGE_CDP_CITRUS_COUNTY = "57058"
PINE_RIDGE_CDP_COLLIER_COUNTY = "57066"
PINECRAFT_CDP = "56525"
PINECREST_VILLAGE = "56625"
PINELAND_CDP = "56875"
PINELLAS_PARK_CITY = "56975"
PINEWOOD_CDP = "57250"
PIONEER_CDP = "57320"
PITTMAN_CDP = "57380"
PLANT_CITY_CITY = "57550"
PLANTATION_CDP = "57450"
PLANTATION_ISLAND_CDP = "57492"
PLANTATION_MOBILE_HOME_PARK_CDP = "57518"
PLANTATION_CITY = "57425"
POINCIANA_CDP = "57900"
POINT_BAKER_CDP = "57908"
POLK_CITY_TOWN = "57950"
POMONA_PARK_TOWN = "58025"
POMPANO_BEACH_CITY = "58050"
PONCE_INLET_TOWN = "58200"
PONCE_DE_LEON_TOWN = "58175"
PORT_CHARLOTTE_CDP = "58350"
PORT_LABELLE_CDP = "58420"
PORT_ORANGE_CITY = "58575"
PORT_RICHEY_CITY = "58600"
PORT_SALERNO_CDP = "58727"
PORT_ST_JOE_CITY = "58675"
PORT_ST_JOHN_CDP = "58700"
PORT_ST_LUCIE_CITY = "58715"
PRETTY_BAYOU_CDP = "58962"
PRINCETON_CDP = "58975"
PROGRESS_VILLAGE_CDP = "59050"
PUNTA_GORDA_CITY = "59200"
PUNTA_RASSA_CDP = "59250"
QUAIL_RIDGE_CDP = "59311"
QUINCY_CITY = "59325"
RAIFORD_TOWN = "59400"
RAINBOW_LAKES_ESTATES_CDP = "59450"
RAINBOW_PARK_CDP = "59466"
RAINBOW_SPRINGS_CDP = "59470"
RALEIGH_CDP = "59475"
REDDICK_TOWN = "59675"
REDINGTON_BEACH_TOWN = "59725"
REDINGTON_SHORES_TOWN = "59750"
RICHMOND_HEIGHTS_CDP = "60225"
RICHMOND_WEST_CDP = "60230"
RIDGE_MANOR_CDP = "60325"
RIDGE_WOOD_HEIGHTS_CDP = "60475"
RIDGECREST_CDP = "60275"
RIO_CDP = "60550"
RIO_PINAR_CDP = "60562"
RIVER_PARK_CDP = "60785"
RIVER_RIDGE_CDP = "60835"
RIVERVIEW_CDP = "60950"
RIVIERA_BEACH_CITY = "60975"
ROCKLEDGE_CITY = "61500"
ROEVILLE_CDP = "61615"
ROOSEVELT_GARDENS_CDP = "61807"
ROSELAND_CDP = "61875"
ROTONDA_CDP = "61937"
ROYAL_PALM_BEACH_VILLAGE = "62100"
ROYAL_PALM_ESTATES_CDP = "62118"
RUSKIN_CDP = "62275"
SAFETY_HARBOR_CITY = "62425"
SAMOSET_CDP = "63225"
SAMSULA_SPRUCE_CREEK_CDP = "63362"
SAN_ANTONIO_CITY = "63375"
SAN_CARLOS_PARK_CDP = "63425"
SAN_CASTLE_CDP = "63435"
SANFORD_CITY = "63650"
SANIBEL_CITY = "63700"
SARASOTA_SPRINGS_CDP = "64325"
SARASOTA_CITY = "64175"
SATELLITE_BEACH_CITY = "64400"
SAWGRASS_CDP = "64525"
SCHALL_CIRCLE_CDP = "64547"
SCOTTSMOOR_CDP = "64625"
SEA_RANCH_LAKES_VILLAGE = "64725"
SEBASTIAN_CITY = "64825"
SEBRING_CITY = "64875"
SEFFNER_CDP = "64925"
SEMINOLE_MANOR_CDP = "65100"
SEMINOLE_CITY = "64975"
SEVILLE_CDP = "65200"
SEWALLS_POINT_TOWN = "65225"
SHADY_HILLS_CDP = "65385"
SHALIMAR_TOWN = "65425"
SHARPES_CDP = "65525"
SIESTA_KEY_CDP = "66000"
SILVER_LAKE_CDP = "66062"
SILVER_SPRINGS_CDP = "66125"
SILVER_SPRINGS_SHORES_CDP = "66175"
SILVER_SPRINGS_SHORES_EAST_CDP = "66179"
SKY_LAKE_CDP = "66425"
SNEADS_TOWN = "66725"
SOLANA_CDP = "66875"
SOPCHOPPY_CITY = "66925"
SORRENTO_CDP = "66975"
SOUTH_APOPKA_CDP = "67163"
SOUTH_BAY_CITY = "67175"
SOUTH_BEACH_CDP = "67192"
SOUTH_BRADENTON_CDP = "67258"
SOUTH_BROOKSVILLE_CDP = "67266"
SOUTH_DAYTONA_CITY = "67325"
SOUTH_GATE_RIDGE_CDP = "67450"
SOUTH_HIGHPOINT_CDP = "67462"
SOUTH_MIAMI_HEIGHTS_CDP = "67575"
SOUTH_MIAMI_CITY = "67550"
SOUTH_PALM_BEACH_TOWN = "67650"
SOUTH_PASADENA_CITY = "67675"
SOUTH_PATRICK_SHORES_CDP = "67725"
SOUTH_SARASOTA_CDP = "67887"
SOUTH_VENICE_CDP = "68100"
SOUTHCHASE_CDP = "67270"
SOUTHEAST_ARCADIA_CDP = "67355"
SOUTHGATE_CDP = "67425"
SOUTHWEST_RANCHES_TOWN = "68135"
SPRING_HILL_CDP = "68350"
SPRING_LAKE_CDP = "68375"
SPRING_RIDGE_CDP = "68435"
SPRINGFIELD_CITY = "68275"
SPRINGHILL_CDP = "68365"
ST_AUGUSTINE_BEACH_CITY = "62525"
ST_AUGUSTINE_SHORES_CDP = "62550"
ST_AUGUSTINE_SOUTH_CDP = "62562"
ST_AUGUSTINE_CITY = "62500"
ST_CLOUD_CITY = "62625"
ST_GEORGE_ISLAND_CDP = "62650"
ST_JAMES_CITY_CDP = "62675"
ST_LEO_TOWN = "62775"
ST_LUCIE_VILLAGE_TOWN = "62800"
ST_MARKS_CITY = "62825"
ST_PETE_BEACH_CITY = "62885"
ST_PETERSBURG_CITY = "63000"
STACEY_STREET_CDP = "68487"
STARKE_CITY = "68525"
STEINHATCHEE_CDP = "68625"
STOCK_ISLAND_CDP = "68800"
STUART_CITY = "68875"
SUGARMILL_WOODS_CDP = "68950"
SUMATRA_CDP = "69025"
SUN_CITY_CENTER_CDP = "69250"
SUNCOAST_ESTATES_CDP = "69275"
SUNNY_ISLES_BEACH_CITY = "69555"
SUNRISE_CITY = "69700"
SUNSET_CDP = "69812"
SURFSIDE_TOWN = "70075"
SWEETWATER_CITY = "70345"
TAFT_CDP = "70525"
TALLAHASSEE_CITY = "70600"
TAMARAC_CITY = "70675"
TAMIAMI_CDP = "70700"
TAMPA_CITY = "71000"
TANGELO_PARK_CDP = "71075"
TANGERINE_CDP = "71100"
TARPON_SPRINGS_CITY = "71150"
TAVARES_CITY = "71225"
TAVERNIER_CDP = "71250"
TAYLOR_CREEK_CDP = "71300"
TEMPLE_TERRACE_CITY = "71400"
TEQUESTA_VILLAGE = "71525"
THE_ACREAGE_CDP = "71564"
THE_CROSSINGS_CDP = "71567"
THE_HAMMOCKS_CDP = "71569"
THE_MEADOWS_CDP = "71580"
THE_VILLAGES_CDP = "71625"
THONOTOSASSA_CDP = "71725"
THREE_LAKES_CDP = "71741"
THREE_OAKS_CDP = "71758"
TICE_CDP = "71800"
TIERRA_VERDE_CDP = "71825"
TIGER_POINT_CDP = "71842"
TILDENVILLE_CDP = "71850"
TIMBER_PINES_CDP = "71867"
TITUSVILLE_CITY = "71900"
TOWN_N_COUNTRY_CDP = "72145"
TREASURE_ISLAND_CITY = "72325"
TRENTON_CITY = "72350"
TRILBY_CDP = "72425"
TRINITY_CDP = "72442"
TROPICAL_PARK_CDP = "72521"
TYNDALL_AFB_CDP = "72875"
UMATILLA_CITY = "73025"
UNION_PARK_CDP = "73075"
UNIVERSITY_CDP_HILLSBOROUGH_COUNTY = "73163"
UNIVERSITY_CDP_ORANGE_COUNTY = "73172"
UPPER_GRAND_LAGOON_CDP = "73312"
VALPARAISO_CITY = "73675"
VALRICO_CDP = "73700"
VAMO_CDP = "73725"
VENICE_GARDENS_CDP = "73950"
VENICE_CITY = "73900"
VERANDAH_CDP = "74016"
VERNON_CITY = "74125"
VERO_BEACH_SOUTH_CDP = "74200"
VERO_BEACH_CITY = "74150"
VERO_LAKE_ESTATES_CDP = "74225"
VERONA_WALK_CDP = "74235"
VIERA_EAST_CDP = "74368"
VIERA_WEST_CDP = "74370"
VILANO_BEACH_CDP = "74400"
VILLAS_CDP = "74512"
VINEYARDS_CDP = "74562"
VIRGINIA_GARDENS_VILLAGE = "74575"
WABASSO_BEACH_CDP = "74635"
WABASSO_CDP = "74625"
WACISSA_CDP = "74700"
WAHNETA_CDP = "74775"
WALDO_CITY = "74925"
WALLACE_CDP = "74975"
WARM_MINERAL_SPRINGS_CDP = "75175"
WARRINGTON_CDP = "75200"
WASHINGTON_PARK_CDP = "75225"
WATERGATE_CDP = "75275"
WATERTOWN_CDP = "75300"
WAUCHULA_CITY = "75375"
WAUKEENAH_CDP = "75425"
WAUSAU_TOWN = "75450"
WAVERLY_CDP = "75475"
WEBSTER_CITY = "75600"
WEDGEFIELD_CDP = "75612"
WEEKI_WACHEE_GARDENS_CDP = "75641"
WEKIWA_SPRINGS_CDP = "75725"
WELAKA_TOWN = "75750"
WELLINGTON_VILLAGE = "75812"
WESLEY_CHAPEL_CDP = "75875"
WEST_BRADENTON_CDP = "76050"
WEST_CANAVERAL_GROVES_CDP = "76058"
WEST_DELAND_CDP = "76087"
WEST_LEALMAN_CDP = "76481"
WEST_LITTLE_RIVER_CDP = "76487"
WEST_MELBOURNE_CITY = "76500"
WEST_MIAMI_CITY = "76525"
WEST_PALM_BEACH_CITY = "76600"
WEST_PARK_CITY = "76658"
WEST_PENSACOLA_CDP = "76675"
WEST_PERRINE_CDP = "76700"
WEST_SAMOSET_CDP = "76740"
WEST_VERO_CORRIDOR_CDP = "76937"
WESTCHASE_CDP = "76062"
WESTCHESTER_CDP = "76075"
WESTGATE_CDP = "76290"
WESTLAKE_CITY = "76417"
WESTON_CITY = "76582"
WESTVIEW_CDP = "76950"
WESTVILLE_TOWN = "76975"
WESTWOOD_LAKES_CDP = "77075"
WEWAHITCHKA_CITY = "77100"
WHISKEY_CREEK_CDP = "77137"
WHITE_CITY_CDP = "77275"
WHITE_SPRINGS_TOWN = "77400"
WHITFIELD_CDP_MANATEE_COUNTY = "77467"
WHITFIELD_CDP_SANTA_ROSA_COUNTY = "77470"
WILDWOOD_CITY = "77675"
WILLIAMSBURG_CDP = "77735"
WILLISTON_HIGHLANDS_CDP = "77837"
WILLISTON_CITY = "77825"
WILLOW_OAK_CDP = "77862"
WILTON_MANORS_CITY = "78000"
WIMAUMA_CDP = "78025"
WINDERMERE_TOWN = "78050"
WINDING_CYPRESS_CDP = "78063"
WINDSOR_CDP = "78110"
WINTER_BEACH_CDP = "78225"
WINTER_GARDEN_CITY = "78250"
WINTER_HAVEN_CITY = "78275"
WINTER_PARK_CITY = "78300"
WINTER_SPRINGS_CITY = "78325"
WISCON_CDP = "78340"
WOODLAWN_BEACH_CDP = "78500"
WOODVILLE_CDP = "78700"
WORLD_GOLF_VILLAGE_CDP = "78740"
WORTHINGTON_SPRINGS_TOWN = "78775"
WRIGHT_CDP = "78800"
YALAHA_CDP = "78900"
YANKEETOWN_TOWN = "78925"
YEEHAW_JUNCTION_CDP = "78975"
YULEE_CDP = "79175"
ZELLWOOD_CDP = "79200"
ZEPHYRHILLS_NORTH_CDP = "79231"
ZEPHYRHILLS_SOUTH_CDP = "79237"
ZEPHYRHILLS_WEST_CDP = "79243"
ZEPHYRHILLS_CITY = "79225"
ZOLFO_SPRINGS_TOWN = "79250"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Nebraska."""


ABIE_VILLAGE = "00205"
ADAMS_VILLAGE = "00240"
AGNEW_CDP = "00380"
AINSWORTH_CITY = "00415"
ALBION_CITY = "00555"
ALDA_VILLAGE = "00625"
ALEXANDRIA_VILLAGE = "00730"
ALLEN_VILLAGE = "00870"
ALLIANCE_CITY = "00905"
ALMA_CITY = "00975"
ALVO_VILLAGE = "01150"
AMES_CDP = "01220"
AMHERST_VILLAGE = "01290"
ANOKA_VILLAGE = "01465"
ANSELMO_VILLAGE = "01500"
ANSLEY_VILLAGE = "01535"
ARAPAHOE_CITY = "01780"
ARCADIA_VILLAGE = "01850"
ARCHER_CDP = "01920"
ARLINGTON_VILLAGE = "01990"
ARNOLD_VILLAGE = "02095"
ARTHUR_VILLAGE = "02200"
ASHLAND_CITY = "02305"
ASHTON_VILLAGE = "02375"
ATEN_CDP = "02480"
ATKINSON_CITY = "02550"
ATLANTA_VILLAGE = "02620"
AUBURN_CITY = "02655"
AURORA_CITY = "02690"
AVOCA_VILLAGE = "02795"
AXTELL_VILLAGE = "02830"
AYR_VILLAGE = "02865"
BANCROFT_VILLAGE = "03005"
BARADA_VILLAGE = "03040"
BARNESTON_VILLAGE = "03075"
BARTLETT_VILLAGE = "03145"
BARTLEY_VILLAGE = "03180"
BASSETT_CITY = "03215"
BATTLE_CREEK_CITY = "03250"
BAYARD_CITY = "03285"
BAZILE_MILLS_VILLAGE = "03355"
BEACON_VIEW_CDP = "03377"
BEATRICE_CITY = "03390"
BEAVER_CITY_CITY = "03495"
BEAVER_CROSSING_VILLAGE = "03530"
BEE_VILLAGE = "03600"
BEEMER_VILLAGE = "03635"
BELDEN_VILLAGE = "03775"
BELGRADE_VILLAGE = "03810"
BELLEVUE_CITY = "03950"
BELLWOOD_VILLAGE = "04020"
BELMAR_CDP = "04055"
BELVIDERE_VILLAGE = "04160"
BENEDICT_VILLAGE = "04195"
BENKELMAN_CITY = "04230"
BENNET_VILLAGE = "04300"
BENNINGTON_CITY = "04405"
BEREA_CDP = "04545"
BERTRAND_VILLAGE = "04615"
BERWYN_VILLAGE = "04650"
BIG_SPRINGS_VILLAGE = "04895"
BLADEN_VILLAGE = "05140"
BLAIR_CITY = "05350"
BLOOMFIELD_CITY = "05455"
BLOOMINGTON_VILLAGE = "05490"
BLUE_HILL_CITY = "05560"
BLUE_SPRINGS_CITY = "05630"
BOW_VALLEY_CDP = "05980"
BOYS_TOWN_VILLAGE = "06015"
BRADSHAW_VILLAGE = "06050"
BRADY_VILLAGE = "06085"
BRAINARD_VILLAGE = "06120"
BREWSTER_VILLAGE = "06260"
BRIDGEPORT_CITY = "06295"
BRISTOW_VILLAGE = "06400"
BROADWATER_VILLAGE = "06470"
BROCK_VILLAGE = "06505"
BROKEN_BOW_CITY = "06610"
BROWNLEE_CDP = "06680"
BROWNVILLE_VILLAGE = "06750"
BRULE_VILLAGE = "06785"
BRUNING_VILLAGE = "06820"
BRUNO_VILLAGE = "06855"
BRUNSWICK_VILLAGE = "06890"
BURCHARD_VILLAGE = "07065"
BURR_VILLAGE = "07205"
BURTON_VILLAGE = "07310"
BURWELL_CITY = "07345"
BUSHNELL_VILLAGE = "07415"
BUTTE_VILLAGE = "07485"
BYRON_VILLAGE = "07555"
CAIRO_VILLAGE = "07625"
CALLAWAY_VILLAGE = "07660"
CAMBRIDGE_CITY = "07730"
CAMPBELL_VILLAGE = "07870"
CARLETON_VILLAGE = "07975"
CARROLL_VILLAGE = "08010"
CEDAR_BLUFFS_VILLAGE = "08150"
CEDAR_CREEK_VILLAGE = "08185"
CEDAR_RAPIDS_VILLAGE = "08220"
CENTER_VILLAGE = "08360"
CENTRAL_CITY_CITY = "08535"
CERESCO_VILLAGE = "08570"
CHADRON_CITY = "08605"
CHALCO_CDP = "08640"
CHAMBERS_VILLAGE = "08675"
CHAMPION_CDP = "08745"
CHAPMAN_VILLAGE = "08780"
CHAPPELL_CITY = "08885"
CHENEY_CDP = "08990"
CHESTER_VILLAGE = "09095"
CLARKS_VILLAGE = "09165"
CLARKSON_CITY = "09200"
CLATONIA_VILLAGE = "09270"
CLAY_CENTER_CITY = "09375"
CLEARWATER_VILLAGE = "09445"
CLINTON_VILLAGE = "09655"
CODY_VILLAGE = "09760"
COLERIDGE_VILLAGE = "09865"
COLON_VILLAGE = "10005"
COLUMBUS_CITY = "10110"
COMSTOCK_VILLAGE = "10180"
CONCORD_VILLAGE = "10250"
COOK_VILLAGE = "10390"
CORDOVA_VILLAGE = "10495"
CORNLEA_VILLAGE = "10600"
CORTLAND_VILLAGE = "10635"
COTESFIELD_VILLAGE = "10740"
COWLES_VILLAGE = "10985"
COZAD_CITY = "11020"
CRAB_ORCHARD_VILLAGE = "11055"
CRAIG_VILLAGE = "11090"
CRAWFORD_CITY = "11195"
CREIGHTON_CITY = "11230"
CRESTON_VILLAGE = "11300"
CRETE_CITY = "11370"
CROFTON_CITY = "11440"
CROOKSTON_VILLAGE = "11475"
CULBERTSON_VILLAGE = "11615"
CURTIS_CITY = "11825"
CUSHING_VILLAGE = "11860"
DAKOTA_CITY_CITY = "12000"
DALTON_VILLAGE = "12070"
DANBURY_VILLAGE = "12105"
DANNEBROG_VILLAGE = "12140"
DAVENPORT_VILLAGE = "12245"
DAVEY_VILLAGE = "12280"
DAVID_CITY_CITY = "12315"
DAWSON_VILLAGE = "12420"
DAYKIN_VILLAGE = "12455"
DE_WITT_VILLAGE = "13015"
DECATUR_VILLAGE = "12525"
DENTON_VILLAGE = "12770"
DESHLER_CITY = "12840"
DEWEESE_VILLAGE = "12945"
DILLER_VILLAGE = "13085"
DIX_VILLAGE = "13190"
DIXON_VILLAGE = "13225"
DODGE_VILLAGE = "13295"
DONIPHAN_VILLAGE = "13365"
DORCHESTER_VILLAGE = "13435"
DOUGLAS_VILLAGE = "13505"
DU_BOIS_VILLAGE = "13750"
DUNBAR_VILLAGE = "13855"
DUNCAN_VILLAGE = "13890"
DUNNING_VILLAGE = "13960"
DWIGHT_VILLAGE = "14065"
EAGLE_VILLAGE = "14100"
EDDYVILLE_VILLAGE = "14380"
EDGAR_CITY = "14450"
EDISON_VILLAGE = "14520"
ELBA_VILLAGE = "14555"
ELGIN_CITY = "14730"
ELK_CREEK_VILLAGE = "14975"
ELM_CREEK_VILLAGE = "15360"
ELMWOOD_VILLAGE = "15430"
ELSIE_VILLAGE = "15500"
ELWOOD_VILLAGE = "15570"
ELYRIA_VILLAGE = "15605"
EMERALD_CDP = "15675"
EMERSON_VILLAGE = "15710"
EMMET_VILLAGE = "15815"
ENDERS_CDP = "15885"
ENDICOTT_VILLAGE = "15920"
ERICSON_VILLAGE = "16025"
EUSTIS_VILLAGE = "16165"
EWING_VILLAGE = "16270"
EXETER_VILLAGE = "16340"
FAIRBURY_CITY = "16410"
FAIRFIELD_CITY = "16445"
FAIRMONT_VILLAGE = "16550"
FALLS_CITY_CITY = "16655"
FARNAM_VILLAGE = "16725"
FARWELL_VILLAGE = "16760"
FILLEY_VILLAGE = "16830"
FIRTH_VILLAGE = "16935"
FONTANELLE_CDP = "17040"
FORDYCE_VILLAGE = "17110"
FORT_CALHOUN_CITY = "17145"
FOSTER_VILLAGE = "17320"
FRANKLIN_CITY = "17530"
FREMONT_CITY = "17670"
FRIEND_CITY = "17775"
FULLERTON_CITY = "17810"
FUNK_VILLAGE = "17880"
GANDY_VILLAGE = "17950"
GARLAND_VILLAGE = "18230"
GARRISON_VILLAGE = "18300"
GENEVA_CITY = "18405"
GENOA_CITY = "18475"
GERING_CITY = "18580"
GIBBON_CITY = "18615"
GILEAD_VILLAGE = "18720"
GILTNER_VILLAGE = "18825"
GLENVIL_VILLAGE = "19070"
GLENWOOD_CDP = "19160"
GOEHNER_VILLAGE = "19245"
GORDON_CITY = "19350"
GOTHENBURG_CITY = "19385"
GRAFTON_VILLAGE = "19455"
GRAND_ISLAND_CITY = "19595"
GRANT_CITY = "19910"
GREELEY_CENTER_VILLAGE = "20050"
GREENWOOD_VILLAGE = "20190"
GRESHAM_VILLAGE = "20225"
GRETNA_CITY = "20260"
GROSS_VILLAGE = "20295"
GUIDE_ROCK_VILLAGE = "20365"
GURLEY_VILLAGE = "20435"
HADAR_VILLAGE = "20470"
HAIGLER_VILLAGE = "20540"
HALLAM_VILLAGE = "20610"
HALSEY_VILLAGE = "20680"
HAMLET_VILLAGE = "20750"
HAMPTON_VILLAGE = "20785"
HARBINE_VILLAGE = "20960"
HARDY_VILLAGE = "20995"
HARRISBURG_CDP = "21030"
HARRISON_VILLAGE = "21240"
HARTINGTON_CITY = "21275"
HARVARD_CITY = "21345"
HASTINGS_CITY = "21415"
HAY_SPRINGS_VILLAGE = "21730"
HAYES_CENTER_VILLAGE = "21660"
HAZARD_VILLAGE = "21765"
HEARTWELL_VILLAGE = "21835"
HEBRON_CITY = "21905"
HEMINGFORD_VILLAGE = "22045"
HENDERSON_CITY = "22080"
HENDLEY_VILLAGE = "22115"
HENRY_VILLAGE = "22150"
HERMAN_VILLAGE = "22185"
HERSHEY_VILLAGE = "22290"
HICKMAN_CITY = "22325"
HILDRETH_VILLAGE = "22430"
HOLBROOK_VILLAGE = "22605"
HOLDREGE_CITY = "22640"
HOLMESVILLE_CDP = "22780"
HOLSTEIN_VILLAGE = "22815"
HOMER_VILLAGE = "22920"
HOOPER_CITY = "23025"
HORDVILLE_VILLAGE = "23200"
HOSKINS_VILLAGE = "23235"
HOWARD_CITY_BOELUS_VILLAGE = "23270"
HOWELLS_VILLAGE = "23340"
HUBBARD_VILLAGE = "23375"
HUBBELL_VILLAGE = "23410"
HUMBOLDT_CITY = "23445"
HUMPHREY_CITY = "23480"
HUNTLEY_VILLAGE = "23550"
HYANNIS_VILLAGE = "23655"
IMPERIAL_CITY = "23690"
INAVALE_CDP = "23725"
INDIANOLA_CITY = "23830"
INGLEWOOD_VILLAGE = "23970"
INLAND_CDP = "24005"
INMAN_VILLAGE = "24075"
ITHACA_VILLAGE = "24285"
JACKSON_VILLAGE = "24355"
JANSEN_VILLAGE = "24530"
JOHNSON_VILLAGE = "24670"
JOHNSTOWN_VILLAGE = "24740"
JULIAN_VILLAGE = "24915"
JUNIATA_VILLAGE = "24950"
KEARNEY_CITY = "25055"
KENESAW_VILLAGE = "25160"
KENNARD_VILLAGE = "25230"
KEYSTONE_CDP = "25335"
KILGORE_VILLAGE = "25405"
KIMBALL_CITY = "25475"
KING_LAKE_CDP = "25510"
KRAMER_CDP = "25720"
LA_PLATTE_CDP = "26315"
LA_VISTA_CITY = "26385"
LAKEVIEW_CDP = "26150"
LAMAR_VILLAGE = "26175"
LAUREL_CITY = "26350"
LAWRENCE_VILLAGE = "26420"
LEBANON_VILLAGE = "26455"
LEIGH_VILLAGE = "26560"
LEMOYNE_CDP = "26595"
LESHARA_VILLAGE = "26630"
LEWELLEN_VILLAGE = "26805"
LEWISTON_VILLAGE = "26875"
LEXINGTON_CITY = "26910"
LIBERTY_VILLAGE = "26980"
LINCOLN_CITY = "28000"
LINDSAY_VILLAGE = "28105"
LINDY_CDP = "28140"
LINOMA_BEACH_CDP = "28165"
LINWOOD_VILLAGE = "28245"
LISCO_CDP = "28315"
LITCHFIELD_VILLAGE = "28350"
LODGEPOLE_VILLAGE = "28420"
LONG_PINE_CITY = "29050"
LOOMIS_VILLAGE = "29085"
LORENZO_CDP = "29120"
LORETTO_CDP = "29155"
LORTON_VILLAGE = "29175"
LOUISVILLE_CITY = "29260"
LOUP_CITY_CITY = "29470"
LUSHTON_VILLAGE = "29645"
LYMAN_VILLAGE = "29715"
LYNCH_VILLAGE = "29750"
LYONS_CITY = "29855"
MACY_CDP = "30170"
MADISON_CITY = "30240"
MADRID_VILLAGE = "30275"
MAGNET_VILLAGE = "30310"
MALCOLM_VILLAGE = "30345"
MALMO_VILLAGE = "30380"
MANLEY_VILLAGE = "30415"
MARQUETTE_VILLAGE = "30730"
MARTELL_CDP = "30835"
MARTIN_CDP = "30905"
MARTINSBURG_VILLAGE = "30940"
MASKELL_VILLAGE = "31045"
MASON_CITY_VILLAGE = "31115"
MAX_CDP = "31150"
MAXWELL_VILLAGE = "31220"
MAYWOOD_VILLAGE = "31325"
MCCOOK_CITY = "29925"
MCCOOL_JUNCTION_VILLAGE = "29960"
MCGREW_VILLAGE = "30030"
MCLEAN_VILLAGE = "30065"
MEAD_VILLAGE = "31395"
MEADOW_GROVE_VILLAGE = "31465"
MELBETA_VILLAGE = "31570"
MELIA_CDP = "31605"
MEMPHIS_VILLAGE = "31640"
MERNA_VILLAGE = "31780"
MERRIMAN_VILLAGE = "31815"
MILFORD_CITY = "32060"
MILLER_VILLAGE = "32130"
MILLIGAN_VILLAGE = "32200"
MINATARE_CITY = "32305"
MINDEN_CITY = "32340"
MITCHELL_CITY = "32410"
MONOWI_VILLAGE = "32550"
MONROE_VILLAGE = "32585"
MOOREFIELD_VILLAGE = "32760"
MORRILL_VILLAGE = "32830"
MORSE_BLUFF_VILLAGE = "32865"
MULLEN_VILLAGE = "33250"
MURDOCK_VILLAGE = "33320"
MURRAY_VILLAGE = "33425"
NAPER_VILLAGE = "33530"
NAPONEE_VILLAGE = "33565"
NEBRASKA_CITY_CITY = "33705"
NEHAWKA_VILLAGE = "33740"
NELIGH_CITY = "33775"
NELSON_CITY = "33880"
NEMAHA_VILLAGE = "33950"
NENZEL_VILLAGE = "33985"
NEWCASTLE_VILLAGE = "34090"
NEWMAN_GROVE_CITY = "34230"
NEWPORT_VILLAGE = "34265"
NICKERSON_VILLAGE = "34300"
NIOBRARA_VILLAGE = "34370"
NORA_VILLAGE = "34545"
NORFOLK_CITY = "34615"
NORMAN_VILLAGE = "34650"
NORTH_BEND_CITY = "34720"
NORTH_LOUP_VILLAGE = "34825"
NORTH_PLATTE_CITY = "35000"
ONEILL_CITY = "37105"
OAK_VILLAGE = "35245"
OAKDALE_VILLAGE = "35385"
OAKLAND_CITY = "35490"
OBERT_VILLAGE = "35560"
OCONTO_VILLAGE = "35665"
OCTAVIA_VILLAGE = "35700"
ODELL_VILLAGE = "35735"
ODESSA_CDP = "35770"
OFFUTT_AFB_CDP = "35875"
OGALLALA_CITY = "35980"
OHIOWA_VILLAGE = "36015"
OMAHA_CITY = "37000"
ONG_VILLAGE = "37140"
ORCHARD_VILLAGE = "37210"
ORD_CITY = "37280"
ORLEANS_VILLAGE = "37420"
OSCEOLA_CITY = "37525"
OSHKOSH_CITY = "37560"
OSMOND_CITY = "37595"
OTOE_VILLAGE = "37630"
OVERLAND_CDP = "37735"
OVERTON_VILLAGE = "37770"
OXFORD_VILLAGE = "37910"
PAGE_VILLAGE = "38085"
PALISADE_VILLAGE = "38130"
PALMER_VILLAGE = "38160"
PALMYRA_VILLAGE = "38190"
PANAMA_VILLAGE = "38225"
PAPILLION_CITY = "38295"
PARKS_CDP = "38365"
PAWNEE_CITY_CITY = "38575"
PAXTON_VILLAGE = "38610"
PENDER_VILLAGE = "38750"
PERU_CITY = "38960"
PETERSBURG_VILLAGE = "38995"
PHILLIPS_VILLAGE = "39030"
PICKRELL_VILLAGE = "39065"
PIERCE_CITY = "39100"
PILGER_VILLAGE = "39135"
PLAINVIEW_CITY = "39170"
PLATTE_CENTER_VILLAGE = "39310"
PLATTSMOUTH_CITY = "39345"
PLEASANT_DALE_VILLAGE = "39380"
PLEASANTON_VILLAGE = "39450"
PLYMOUTH_VILLAGE = "39590"
POLK_VILLAGE = "39660"
PONCA_CITY = "39695"
POOLE_CDP = "39835"
POTTER_VILLAGE = "39870"
PRAGUE_VILLAGE = "39975"
PRAIRIE_HOME_CDP = "40255"
PRESTON_VILLAGE = "40325"
PRIMROSE_VILLAGE = "40360"
PRINCETON_CDP = "40395"
PROSSER_VILLAGE = "40430"
RAEVILLE_CDP = "40535"
RAGAN_VILLAGE = "40570"
RALSTON_CITY = "40605"
RANDOLPH_CITY = "40675"
RAVENNA_CITY = "40710"
RAYMOND_VILLAGE = "40780"
RED_CLOUD_CITY = "40920"
REPUBLICAN_CITY_VILLAGE = "41130"
REYNOLDS_VILLAGE = "41235"
RICHFIELD_CDP = "41340"
RICHLAND_VILLAGE = "41375"
RISING_CITY_VILLAGE = "41480"
RIVERDALE_VILLAGE = "41515"
RIVERTON_VILLAGE = "41760"
ROCA_VILLAGE = "41830"
ROCKVILLE_VILLAGE = "42075"
ROGERS_VILLAGE = "42145"
ROSALIE_VILLAGE = "42250"
ROSCOE_CDP = "42285"
ROSELAND_VILLAGE = "42355"
ROYAL_VILLAGE = "42495"
RULO_VILLAGE = "42670"
RUSHVILLE_CITY = "42775"
RUSKIN_VILLAGE = "42810"
SALEM_VILLAGE = "43370"
SANTEE_VILLAGE = "43475"
SARBEN_CDP = "43650"
SARGENT_CITY = "43685"
SARONVILLE_VILLAGE = "43755"
SCHUYLER_CITY = "44035"
SCOTIA_VILLAGE = "44070"
SCOTTSBLUFF_CITY = "44245"
SCRIBNER_CITY = "44280"
SENECA_CDP = "44385"
SEWARD_CITY = "44420"
SHELBY_VILLAGE = "44595"
SHELTON_VILLAGE = "44700"
SHICKLEY_VILLAGE = "45085"
SHOLES_VILLAGE = "45190"
SHUBERT_VILLAGE = "45225"
SIDNEY_CITY = "45295"
SILVER_CREEK_VILLAGE = "45400"
SMITHFIELD_VILLAGE = "45575"
SNYDER_VILLAGE = "45610"
SOUTH_BEND_VILLAGE = "45680"
SOUTH_SIOUX_CITY_CITY = "46030"
SPALDING_VILLAGE = "46135"
SPENCER_VILLAGE = "46275"
SPRAGUE_VILLAGE = "46380"
SPRINGFIELD_CITY = "46520"
SPRINGVIEW_VILLAGE = "46625"
ST_EDWARD_CITY = "43055"
ST_HELENA_VILLAGE = "43090"
ST_LIBORY_CDP = "43160"
ST_PAUL_CITY = "43265"
STAMFORD_VILLAGE = "46695"
STANTON_CITY = "46800"
STAPLEHURST_VILLAGE = "46835"
STAPLETON_VILLAGE = "46870"
STEELE_CITY_VILLAGE = "47010"
STEINAUER_VILLAGE = "47080"
STELLA_VILLAGE = "47115"
STERLING_VILLAGE = "47150"
STOCKHAM_VILLAGE = "47220"
STOCKVILLE_VILLAGE = "47290"
STRANG_VILLAGE = "47360"
STRATTON_VILLAGE = "47395"
STROMSBURG_CITY = "47465"
STUART_VILLAGE = "47500"
SUMNER_VILLAGE = "47675"
SUNOL_CDP = "47745"
SUPERIOR_CITY = "47815"
SURPRISE_VILLAGE = "47850"
SUTHERLAND_VILLAGE = "47920"
SUTTON_CITY = "47955"
SWANTON_VILLAGE = "48060"
SYRACUSE_CITY = "48235"
TABLE_ROCK_VILLAGE = "48270"
TALMAGE_VILLAGE = "48305"
TAMORA_CDP = "48340"
TARNOV_VILLAGE = "48410"
TAYLOR_VILLAGE = "48445"
TECUMSEH_CITY = "48480"
TEKAMAH_CITY = "48515"
TERRYTOWN_CITY = "48585"
THAYER_VILLAGE = "48690"
THEDFORD_VILLAGE = "48760"
THURSTON_VILLAGE = "48900"
TILDEN_CITY = "48935"
TOBIAS_VILLAGE = "49005"
TRENTON_VILLAGE = "49145"
TRUMBULL_VILLAGE = "49285"
TRYON_CDP = "49320"
UEHLING_VILLAGE = "49425"
ULYSSES_VILLAGE = "49460"
UNADILLA_VILLAGE = "49530"
UNION_VILLAGE = "49635"
UPLAND_VILLAGE = "49880"
UTICA_VILLAGE = "49915"
VALENTINE_CITY = "49950"
VALLEY_CITY = "50020"
VALPARAISO_VILLAGE = "50125"
VENANGO_VILLAGE = "50230"
VENICE_CDP = "50265"
VERDEL_VILLAGE = "50335"
VERDIGRE_VILLAGE = "50370"
VERDON_VILLAGE = "50510"
VIRGINIA_VILLAGE = "50790"
WACO_VILLAGE = "50895"
WAHOO_CITY = "50965"
WAKEFIELD_CITY = "51070"
WALLACE_VILLAGE = "51175"
WALTHILL_VILLAGE = "51245"
WALTON_CDP = "51280"
WANN_CDP = "51350"
WASHINGTON_VILLAGE = "51595"
WATERBURY_VILLAGE = "51630"
WATERLOO_VILLAGE = "51665"
WAUNETA_VILLAGE = "51700"
WAUSA_VILLAGE = "51735"
WAVERLY_CITY = "51770"
WAYNE_CITY = "51840"
WEEPING_WATER_CITY = "52015"
WELLFLEET_VILLAGE = "52085"
WEST_POINT_CITY = "52575"
WESTERN_VILLAGE = "52295"
WESTERVILLE_CDP = "52330"
WESTON_VILLAGE = "52540"
WHITE_CLAY_CDP = "52855"
WHITNEY_VILLAGE = "52925"
WILBER_CITY = "52960"
WILCOX_VILLAGE = "52995"
WILLOW_ISLAND_CDP = "53205"
WILSONVILLE_VILLAGE = "53240"
WINNEBAGO_VILLAGE = "53275"
WINNETOON_VILLAGE = "53345"
WINSIDE_VILLAGE = "53380"
WINSLOW_VILLAGE = "53415"
WISNER_CITY = "53450"
WOLBACH_VILLAGE = "53520"
WOOD_LAKE_VILLAGE = "53555"
WOOD_RIVER_CITY = "53660"
WOODLAND_HILLS_CDP = "53575"
WOODLAND_PARK_CDP = "53580"
WYMORE_CITY = "53835"
WYNOT_VILLAGE = "53905"
YANKEE_HILL_CDP = "54020"
YORK_CITY = "54045"
YUTAN_CITY = "54115"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Alaska."""


ADAK_CITY = "00065"
AKHIOK_CITY = "00650"
AKIACHAK_CDP = "00760"
AKIAK_CITY = "00870"
AKUTAN_CITY = "01090"
ALAKANUK_CITY = "01200"
ALATNA_CDP = "01305"
ALCAN_BORDER_CDP = "01390"
ALEKNAGIK_CITY = "01420"
ALENEVA_CDP = "01560"
ALLAKAKET_CITY = "01860"
AMBLER_CITY = "01970"
ANAKTUVUK_PASS_CITY = "02080"
ANCHOR_POINT_CDP = "03110"
ANCHORAGE_MUNICIPALITY = "03000"
ANDERSON_CITY = "03220"
ANGOON_CITY = "03440"
ANIAK_CITY = "03550"
ANVIK_CITY = "03880"
ARCTIC_VILLAGE_CDP = "03990"
ATKA_CITY = "04210"
ATMAUTLUAK_CDP = "04430"
ATQASUK_CITY = "04500"
ATTU_STATION_CDP = "04670"
BADGER_CDP = "05000"
BEAR_CREEK_CDP = "05585"
BEAVER_CDP = "05750"
BELUGA_CDP = "06245"
BETHEL_CITY = "06520"
BETTLES_CITY = "06630"
BIG_DELTA_CDP = "06850"
BIG_LAKE_CDP = "07070"
BIRCH_CREEK_CDP = "07620"
BREVIG_MISSION_CITY = "08740"
BUCKLAND_CITY = "09600"
BUFFALO_SOAPSTONE_CDP = "09657"
BUTTE_CDP = "09710"
CANTWELL_CDP = "10150"
CENTRAL_CDP = "11690"
CHALKYITSIK_CDP = "11800"
CHASE_CDP = "12350"
CHEFORNAK_CITY = "12680"
CHENA_RIDGE_CDP = "12920"
CHENEGA_CDP = "12970"
CHEVAK_CITY = "13230"
CHICKALOON_CDP = "13340"
CHICKEN_CDP = "13450"
CHIGNIK_LAGOON_CDP = "13670"
CHIGNIK_LAKE_CDP = "13780"
CHIGNIK_CITY = "13550"
CHINIAK_CDP = "13860"
CHISANA_CDP = "13890"
CHISTOCHINA_CDP = "14000"
CHITINA_CDP = "14110"
CHUATHBALUK_CITY = "14330"
CIRCLE_CDP = "14880"
CLAM_GULCH_CDP = "15320"
CLARKS_POINT_CITY = "15430"
COFFMAN_COVE_CITY = "16360"
COHOE_CDP = "16420"
COLD_BAY_CITY = "16530"
COLDFOOT_CDP = "16630"
COLLEGE_CDP = "16750"
COOPER_LANDING_CDP = "17190"
COPPER_CENTER_CDP = "17300"
CORDOVA_CITY = "17410"
COVENANT_LIFE_CDP = "17670"
CRAIG_CITY = "17740"
CROOKED_CREEK_CDP = "17850"
CROWN_POINT_CDP = "17960"
DEERING_CITY = "18510"
DELTA_JUNCTION_CITY = "18620"
DELTANA_CDP = "18675"
DENALI_PARK_CDP = "18805"
DIAMOND_RIDGE_CDP = "18925"
DILLINGHAM_CITY = "18950"
DIOMEDE_CITY = "19060"
DOT_LAKE_CDP = "19720"
DOT_LAKE_VILLAGE_CDP = "19750"
DRY_CREEK_CDP = "20020"
EAGLE_VILLAGE_CDP = "20600"
EAGLE_CITY = "20380"
EARECKSON_STATION_CDP = "20716"
EDNA_BAY_CITY = "20970"
EEK_CITY = "21040"
EGEGIK_CITY = "21150"
EIELSON_AFB_CDP = "21370"
EKWOK_CITY = "21810"
ELFIN_COVE_CDP = "22140"
ELIM_CITY = "22250"
EMMONAK_CITY = "22910"
ESTER_CDP = "23460"
EUREKA_ROADHOUSE_CDP = "23720"
EVANSVILLE_CDP = "23790"
EXCURSION_INLET_CDP = "23900"
FAIRBANKS_CITY = "24230"
FALSE_PASS_CITY = "24660"
FARM_LOOP_CDP = "25000"
FARMERS_LOOP_CDP = "24980"
FERRY_CDP = "25220"
FISHHOOK_CDP = "25550"
FLAT_CDP = "25880"
FORT_GREELY_CDP = "26100"
FORT_YUKON_CITY = "26760"
FOUR_MILE_ROAD_CDP = "26835"
FOX_CDP = "26870"
FOX_RIVER_CDP = "26910"
FRITZ_CREEK_CDP = "27090"
FUNNY_RIVER_CDP = "27145"
GAKONA_CDP = "27420"
GALENA_CITY = "27530"
GAMBELL_CITY = "27640"
GAME_CREEK_CDP = "27700"
GATEWAY_CDP = "28200"
GLACIER_VIEW_CDP = "28590"
GLENNALLEN_CDP = "28740"
GOLDSTREAM_CDP = "29130"
GOLOVIN_CITY = "29180"
GOODNEWS_BAY_CITY = "29290"
GRAYLING_CITY = "30060"
GULKANA_CDP = "30500"
GUSTAVUS_CITY = "30940"
HAINES_CDP = "31050"
HALIBUT_COVE_CDP = "31270"
HAPPY_VALLEY_CDP = "31710"
HARDING_BIRCH_LAKES_CDP = "31765"
HEALY_CDP = "32150"
HEALY_LAKE_CDP = "32310"
HOBART_BAY_CDP = "32550"
HOLLIS_CDP = "32810"
HOLY_CROSS_CITY = "33030"
HOMER_CITY = "33140"
HOONAH_CITY = "33360"
HOOPER_BAY_CITY = "33470"
HOPE_CDP = "33580"
HOUSTON_CITY = "33800"
HUGHES_CITY = "33910"
HUSLIA_CITY = "34350"
HYDABURG_CITY = "34460"
HYDER_CDP = "34570"
IGIUGIG_CDP = "34790"
ILIAMNA_CDP = "35120"
IVANOF_BAY_CDP = "35890"
JUNEAU_CITY_AND_BOROUGH = "36400"
KACHEMAK_CITY = "36540"
KAKE_CITY = "36770"
KAKTOVIK_CITY = "36990"
KALIFORNSKY_CDP = "37250"
KALTAG_CITY = "37430"
KARLUK_CDP = "37540"
KASAAN_CITY = "37650"
KASIGLUK_CDP = "37975"
KASILOF_CDP = "38090"
KENAI_CITY = "38420"
KENNY_LAKE_CDP = "38910"
KETCHIKAN_CITY = "38970"
KIANA_CITY = "39300"
KING_COVE_CITY = "39410"
KING_SALMON_CDP = "39630"
KIPNUK_CDP = "39740"
KIVALINA_CITY = "39960"
KLAWOCK_CITY = "40400"
KLUKWAN_CDP = "40510"
KNIK_RIVER_CDP = "40670"
KNIK_FAIRVIEW_CDP = "40645"
KOBUK_CITY = "40840"
KODIAK_STATION_CDP = "41210"
KODIAK_CITY = "40950"
KOKHANOK_CDP = "41280"
KOLIGANEK_CDP = "41500"
KONGIGANAK_CDP = "41610"
KOTLIK_CITY = "41720"
KOTZEBUE_CITY = "41830"
KOYUK_CITY = "41940"
KOYUKUK_CITY = "42050"
KUPREANOF_CITY = "42160"
KWETHLUK_CITY = "42380"
KWIGILLINGOK_CDP = "42490"
LAKE_LOUISE_CDP = "42805"
LAKE_MINCHUMINA_CDP = "42820"
LARSEN_BAY_CITY = "43040"
LAZY_MOUNTAIN_CDP = "43260"
LEVELOCK_CDP = "43810"
LIME_VILLAGE_CDP = "44030"
LIVENGOOD_CDP = "44580"
LORING_CDP = "45020"
LOWELL_POINT_CDP = "45295"
LOWER_KALSKAG_CITY = "45460"
LUTAK_CDP = "45700"
MANLEY_HOT_SPRINGS_CDP = "46780"
MANOKOTAK_CITY = "46890"
MARSHALL_CITY = "47000"
MCCARTHY_CDP = "45790"
MCGRATH_CITY = "46010"
MEADOW_LAKES_CDP = "47735"
MEKORYUK_CITY = "47990"
MENDELTNA_CDP = "48200"
MENTASTA_LAKE_CDP = "48540"
MERTARVIK_CDP = "48590"
METLAKATLA_CDP = "48870"
MILL_BAY_CDP = "49200"
MINTO_CDP = "49530"
MOOSE_CREEK_CDP = "50080"
MOOSE_PASS_CDP = "50190"
MOSQUITO_LAKE_CDP = "50800"
MOUNTAIN_VILLAGE_CITY = "51180"
MUD_BAY_CDP = "51455"
NABESNA_CDP = "51960"
NAKNEK_CDP = "52060"
NANWALEK_CDP = "52210"
NAPAKIAK_CITY = "52390"
NAPASKIAK_CITY = "52720"
NAUKATI_BAY_CDP = "52845"
NELCHINA_CDP = "52915"
NELSON_LAGOON_CDP = "52940"
NENANA_CITY = "53050"
NEW_STUYAHOK_CITY = "53710"
NEWHALEN_CITY = "53270"
NEWTOK_CDP = "53820"
NIGHTMUTE_CITY = "53930"
NIKISKI_CDP = "54050"
NIKOLAEVSK_CDP = "54085"
NIKOLAI_CITY = "54150"
NIKOLSKI_CDP = "54260"
NINILCHIK_CDP = "54480"
NOATAK_CDP = "54700"
NOME_CITY = "54920"
NONDALTON_CITY = "55030"
NOORVIK_CITY = "55140"
NORTH_LAKES_CDP = "55745"
NORTH_POLE_CITY = "55910"
NORTHWAY_CDP = "56220"
NUIQSUT_CITY = "56320"
NULATO_CITY = "56350"
NUNAM_IQUA_CITY = "56600"
NUNAPITCHUK_CITY = "56680"
OLD_HARBOR_CITY = "57340"
OSCARVILLE_CDP = "58330"
OUZINKIE_CITY = "58550"
PALMER_CITY = "58660"
PAXSON_CDP = "59320"
PEDRO_BAY_CDP = "59540"
PELICAN_CITY = "59650"
PERRYVILLE_CDP = "60200"
PETERSBURG_CDP = "60310"
PETERSVILLE_CDP = "60460"
PILOT_POINT_CITY = "60640"
PILOT_STATION_CITY = "60750"
PITKAS_POINT_CDP = "60860"
PLATINUM_CITY = "61080"
PLEASANT_VALLEY_CDP = "61120"
POINT_BAKER_CDP = "61190"
POINT_HOPE_CITY = "61630"
POINT_LAY_CDP = "61700"
POINT_MACKENZIE_CDP = "61788"
POINT_POSSESSION_CDP = "61825"
POPE_VANNOY_LANDING_CDP = "62125"
PORT_ALEXANDER_CITY = "62510"
PORT_ALSWORTH_CDP = "62620"
PORT_CLARENCE_CDP = "63170"
PORT_GRAHAM_CDP = "63280"
PORT_HEIDEN_CITY = "63390"
PORT_LIONS_CITY = "63610"
PORT_PROTECTION_CDP = "63870"
PORTAGE_CREEK_CDP = "62285"
PRIMROSE_CDP = "64240"
PRUDHOE_BAY_CDP = "64380"
QUINHAGAK_CITY = "64600"
RAMPART_CDP = "64820"
RED_DEVIL_CDP = "64930"
RED_DOG_MINE_CDP = "64980"
RIDGEWAY_CDP = "65345"
RUBY_CITY = "65590"
RUSSIAN_MISSION_CITY = "65700"
SALAMATOF_CDP = "66510"
SALCHA_CDP = "66550"
SAND_POINT_CITY = "67020"
SAVOONGA_CITY = "67460"
SAXMAN_CITY = "67570"
SCAMMON_BAY_CITY = "67680"
SELAWIK_CITY = "68230"
SELDOVIA_VILLAGE_CDP = "68370"
SELDOVIA_CITY = "68340"
SEWARD_CITY = "68560"
SHAGELUK_CITY = "68670"
SHAKTOOLIK_CITY = "68890"
SHISHMAREF_CITY = "69770"
SHUNGNAK_CITY = "70100"
SILVER_SPRINGS_CDP = "70320"
SITKA_CITY_AND_BOROUGH = "70540"
SKAGWAY_CDP = "70760"
SKWENTNA_CDP = "70870"
SLANA_CDP = "70930"
SLEETMUTE_CDP = "71090"
SOLDOTNA_CITY = "71640"
SOUTH_LAKES_CDP = "72135"
SOUTH_NAKNEK_CDP = "72190"
SOUTH_VAN_HORN_CDP = "72230"
ST_GEORGE_CITY = "65800"
ST_MARYS_CITY = "66140"
ST_MICHAEL_CITY = "66360"
ST_PAUL_CITY = "66470"
STEBBINS_CITY = "72960"
STEELE_CREEK_CDP = "72985"
STERLING_CDP = "73070"
STEVENS_VILLAGE_CDP = "73290"
STONY_RIVER_CDP = "73400"
SUNRISE_CDP = "73950"
SUSITNA_CDP = "74340"
SUSITNA_NORTH_CDP = "74350"
SUTTON_ALPINE_CDP = "74525"
TAKOTNA_CDP = "74610"
TALKEETNA_CDP = "74830"
TANACROSS_CDP = "75050"
TANAINA_CDP = "75077"
TANANA_CITY = "75160"
TATITLEK_CDP = "75380"
TAZLINA_CDP = "75480"
TELLER_CITY = "75930"
TENAKEE_SPRINGS_CITY = "76260"
TETLIN_CDP = "76590"
THORNE_BAY_CITY = "77140"
TOGIAK_CITY = "77690"
TOK_CDP = "77800"
TOKSOOK_BAY_CITY = "78240"
TOLSONA_CDP = "78297"
TONSINA_CDP = "78350"
TRAPPER_CREEK_CDP = "78680"
TULUKSAK_CDP = "78790"
TUNTUTULIAK_CDP = "79120"
TUNUNAK_CDP = "79230"
TWIN_HILLS_CDP = "79780"
TWO_RIVERS_CDP = "79830"
TYONEK_CDP = "79890"
UGASHIK_CDP = "80100"
UNALAKLEET_CITY = "80660"
UNALASKA_CITY = "80770"
UPPER_KALSKAG_CITY = "81320"
UTQIAĠVIK_CITY = "81920"
VALDEZ_CITY = "82200"
VENETIE_CDP = "82420"
WAINWRIGHT_CITY = "82750"
WALES_CITY = "82860"
WASILLA_CITY = "83080"
WHALE_PASS_CITY = "84000"
WHITE_MOUNTAIN_CITY = "84070"
WHITESTONE_CDP = "84120"
WHITESTONE_LOGGING_CAMP_CDP = "84200"
WHITTIER_CITY = "84510"
WILLOW_CDP = "85280"
WILLOW_CREEK_CDP = "85290"
WISEMAN_CDP = "85610"
WOMENS_BAY_CDP = "85680"
WRANGELL_CITY_AND_BOROUGH = "86380"
YAKUTAT_CDP = "86490"



# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Florida."""


ALACHUA = "001"
BAKER = "003"
BAY = "005"
BRADFORD = "007"
BREVARD = "009"
BROWARD = "011"
CALHOUN = "013"
CHARLOTTE = "015"
CITRUS = "017"
CLAY = "019"
COLLIER = "021"
COLUMBIA = "023"
DESOTO = "027"
DIXIE = "029"
DUVAL = "031"
ESCAMBIA = "033"
FLAGLER = "035"
FRANKLIN = "037"
GADSDEN = "039"
GILCHRIST = "041"
GLADES = "043"
GULF = "045"
HAMILTON = "047"
HARDEE = "049"
HENDRY = "051"
HERNANDO = "053"
HIGHLANDS = "055"
HILLSBOROUGH = "057"
HOLMES = "059"
INDIAN_RIVER = "061"
JACKSON = "063"
JEFFERSON = "065"
LAFAYETTE = "067"
LAKE = "069"
LEE = "071"
LEON = "073"
LEVY = "075"
LIBERTY = "077"
MADISON = "079"
MANATEE = "081"
MARION = "083"
MARTIN = "085"
MIAMI_DADE = "086"
MONROE = "087"
NASSAU = "089"
OKALOOSA = "091"
OKEECHOBEE = "093"
ORANGE = "095"
OSCEOLA = "097"
PALM_BEACH = "099"
PASCO = "101"
PINELLAS = "103"
POLK = "105"
PUTNAM = "107"
SANTA_ROSA = "113"
SARASOTA = "115"
SEMINOLE = "117"
ST_JOHNS = "109"
ST_LUCIE = "111"
SUMTER = "119"
SUWANNEE = "121"
TAYLOR = "123"
UNION = "125"
VOLUSIA = "127"
WAKULLA = "129"
WALTON = "131"
WASHINGTON = "133"



# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Pennsylvania."""


ADAMS = "001"
ALLEGHENY = "003"
ARMSTRONG = "005"
BEAVER = "007"
BEDFORD = "009"
BERKS = "011"
BLAIR = "013"
BRADFORD = "015"
BUCKS = "017"
BUTLER = "019"
CAMBRIA = "021"
CAMERON = "023"
CARBON = "025"
CENTRE = "027"
CHESTER = "029"
CLARION = "031"
CLEARFIELD = "033"
CLINTON = "035"
COLUMBIA = "037"
CRAWFORD = "039"
CUMBERLAND = "041"
DAUPHIN = "043"
DELAWARE = "045"
ELK = "047"
ERIE = "049"
FAYETTE = "051"
FOREST = "053"
FRANKLIN = "055"
FULTON = "057"
GREENE = "059"
HUNTINGDON = "061"
INDIANA = "063"
JEFFERSON = "065"
JUNIATA = "067"
LACKAWANNA = "069"
LANCASTER = "071"
LAWRENCE = "073"
LEBANON = "075"
LEHIGH = "077"
LUZERNE = "079"
LYCOMING = "081"
MCKEAN = "083"
MERCER = "085"
MIFFLIN = "087"
MONROE = "089"
MONTGOMERY = "091"
MONTOUR = "093"
NORTHAMPTON = "095"
NORTHUMBERLAND = "097"
PERRY = "099"
PHILADELPHIA = "101"
PIKE = "103"
POTTER = "105"
SCHUYLKILL = "107"
SNYDER = "109"
SOMERSET = "111"
SULLIVAN = "113"
SUSQUEHANNA = "115"
TIOGA = "117"
UNION = "119"
VENANGO = "121"
WARREN = "123"
WASHINGTON = "125"
WAYNE = "127"
WESTMORELAND = "129"
WYOMING = "131"
YORK = "133"



# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Massachusetts."""


BARNSTABLE = "001"
BERKSHIRE = "003"
BRISTOL = "005"
DUKES = "007"
ESSEX = "009"
FRANKLIN = "011"
HAMPDEN = "013"
HAMPSHIRE = "015"
MIDDLESEX = "017"
NANTUCKET = "019"
NORFOLK = "021"
PLYMOUTH = "023"
SUFFOLK = "025"
WORCESTER = "027"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Minnesota."""


ADA_CITY = "00172"
ADAMS_CITY = "00190"
ADRIAN_CITY = "00262"
AFTON_CITY = "00316"
AITKIN_CITY = "00460"
AKELEY_CITY = "00496"
ALBANY_CITY = "00622"
ALBERT_LEA_CITY = "00694"
ALBERTA_CITY = "00676"
ALBERTVILLE_CITY = "00730"
ALDEN_CITY = "00838"
ALDRICH_CITY = "00892"
ALEXANDRIA_CITY = "00928"
ALPHA_CITY = "01162"
ALTURA_CITY = "01234"
ALVARADO_CITY = "01252"
AMBOY_CITY = "01324"
ANDOVER_CITY = "01486"
ANGLE_INLET_CDP = "01558"
ANNANDALE_CITY = "01684"
ANOKA_CITY = "01720"
APPLE_VALLEY_CITY = "01900"
APPLETON_CITY = "01864"
ARCO_CITY = "01972"
ARDEN_HILLS_CITY = "02026"
ARGYLE_CITY = "02134"
ARLINGTON_CITY = "02152"
ASHBY_CITY = "02422"
ASKOV_CITY = "02548"
ATWATER_CITY = "02692"
AUDUBON_CITY = "02728"
AURORA_CITY = "02872"
AUSTIN_CITY = "02908"
AVOCA_CITY = "03052"
AVON_CITY = "03070"
BABBITT_CITY = "03106"
BACKUS_CITY = "03124"
BADGER_CITY = "03160"
BAGLEY_CITY = "03196"
BAKER_CDP = "03214"
BALATON_CITY = "03250"
BALL_CLUB_CDP = "03376"
BARNESVILLE_CITY = "03574"
BARNUM_CITY = "03628"
BARRETT_CITY = "03682"
BARRY_CITY = "03718"
BATTLE_LAKE_CITY = "03970"
BAUDETTE_CITY = "04024"
BAXTER_CITY = "04042"
BAYPORT_CITY = "04114"
BEARDSLEY_CITY = "04204"
BEAULIEU_CDP = "04348"
BEAVER_BAY_CITY = "04456"
BEAVER_CREEK_CITY = "04492"
BECKER_CITY = "04618"
BEJOU_CITY = "04672"
BELGRADE_CITY = "04762"
BELLE_PLAINE_CITY = "04834"
BELLECHESTER_CITY = "04798"
BELLINGHAM_CITY = "04960"
BELTRAMI_CITY = "05014"
BELVIEW_CITY = "05050"
BEMIDJI_CITY = "05068"
BENA_CITY = "05104"
BENSON_CITY = "05212"
BERTHA_CITY = "05482"
BETHEL_CITY = "05554"
BIG_FALLS_CITY = "05680"
BIG_LAKE_CDP = "05744"
BIG_LAKE_CITY = "05752"
BIGELOW_CITY = "05644"
BIGFORK_CITY = "05698"
BINGHAM_LAKE_CITY = "05896"
BIRCHWOOD_VILLAGE_CITY = "06058"
BIRD_ISLAND_CITY = "06076"
BISCAY_CITY = "06112"
BIWABIK_CITY = "06148"
BLACKDUCK_CITY = "06256"
BLAINE_CITY = "06382"
BLOMKEST_CITY = "06490"
BLOOMING_PRAIRIE_CITY = "06580"
BLOOMINGTON_CITY = "06616"
BLUE_EARTH_CITY = "06688"
BLUFFTON_CITY = "06778"
BOCK_CITY = "06814"
BORUP_CITY = "07030"
BOVEY_CITY = "07048"
BOWLUS_CITY = "07066"
BOY_RIVER_CITY = "07174"
BOYD_CITY = "07138"
BRAHAM_CITY = "07282"
BRAINERD_CITY = "07300"
BRANDON_CITY = "07336"
BRECKENRIDGE_CITY = "07462"
BREEZY_POINT_CITY = "07516"
BREWSTER_CITY = "07660"
BRICELYN_CITY = "07678"
BROOK_PARK_CITY = "07984"
BROOKLYN_CENTER_CITY = "07948"
BROOKLYN_PARK_CITY = "07966"
BROOKS_CITY = "08038"
BROOKSTON_CITY = "08056"
BROOTEN_CITY = "08092"
BROWERVILLE_CITY = "08110"
BROWNS_VALLEY_CITY = "08200"
BROWNSDALE_CITY = "08164"
BROWNSVILLE_CITY = "08218"
BROWNTON_CITY = "08254"
BRUNO_CITY = "08290"
BUCKMAN_CITY = "08416"
BUFFALO_LAKE_CITY = "08488"
BUFFALO_CITY = "08452"
BUHL_CITY = "08524"
BURNSVILLE_CITY = "08794"
BURTRUM_CITY = "08902"
BUTTERFIELD_CITY = "08992"
BYRON_CITY = "09154"
CALEDONIA_CITY = "09226"
CALLAWAY_CITY = "09280"
CALUMET_CITY = "09316"
CAMBRIDGE_CITY = "09370"
CAMPBELL_CITY = "09496"
CANBY_CITY = "09604"
CANNON_FALLS_CITY = "09730"
CANTON_CITY = "09802"
CARLOS_CITY = "09964"
CARLTON_CITY = "10018"
CARVER_CITY = "10144"
CASS_LAKE_CITY = "10252"
CEDAR_MILLS_CITY = "10468"
CENTER_CITY_CITY = "10576"
CENTERVILLE_CITY = "10648"
CEYLON_CITY = "10792"
CHAMPLIN_CITY = "10846"
CHANDLER_CITY = "10900"
CHANHASSEN_CITY = "10918"
CHASKA_CITY = "10972"
CHATFIELD_CITY = "11008"
CHICKAMAW_BEACH_CITY = "11296"
CHISAGO_CITY_CITY = "11350"
CHISHOLM_CITY = "11386"
CHOKIO_CITY = "11440"
CIRCLE_PINES_CITY = "11494"
CLARA_CITY_CITY = "11548"
CLAREMONT_CITY = "11566"
CLARISSA_CITY = "11602"
CLARKFIELD_CITY = "11656"
CLARKS_GROVE_CITY = "11674"
CLEAR_LAKE_CITY = "11764"
CLEARBROOK_CITY = "11746"
CLEARWATER_CITY = "11800"
CLEMENTS_CITY = "11836"
CLEVELAND_CITY = "11872"
CLIMAX_CITY = "11962"
CLINTON_CITY = "11980"
CLITHERALL_CITY = "12088"
CLONTARF_CITY = "12124"
CLOQUET_CITY = "12160"
COATES_CITY = "12376"
COBDEN_CITY = "12394"
COHASSET_CITY = "12412"
COKATO_CITY = "12430"
COLD_SPRING_CITY = "12484"
COLERAINE_CITY = "12502"
COLOGNE_CITY = "12664"
COLUMBIA_HEIGHTS_CITY = "12700"
COLUMBUS_CITY = "12718"
COMFREY_CITY = "12772"
COMSTOCK_CITY = "12862"
CONGER_CITY = "12952"
COOK_CITY = "13006"
COON_RAPIDS_CITY = "13114"
CORCORAN_CITY = "13168"
CORRELL_CITY = "13384"
COSMOS_CITY = "13420"
COTTAGE_GROVE_CITY = "13456"
COTTONWOOD_CITY = "13564"
COURTLAND_CITY = "13582"
CREDIT_RIVER_CITY = "13708"
CROMWELL_CITY = "13780"
CROOKSTON_CITY = "13870"
CROSBY_CITY = "13924"
CROSSLAKE_CITY = "13978"
CROWN_COLLEGE_CDP = "14054"
CRYSTAL_CITY = "14158"
CURRIE_CITY = "14320"
CUYUNA_CITY = "14428"
CYRUS_CITY = "14446"
DAKOTA_CITY = "14518"
DALTON_CITY = "14626"
DANUBE_CITY = "14716"
DANVERS_CITY = "14734"
DARFUR_CITY = "14770"
DARWIN_CITY = "14842"
DASSEL_CITY = "14878"
DAWSON_CITY = "14968"
DAYTON_CITY = "15022"
DE_GRAFF_CITY = "15418"
DEEPHAVEN_CITY = "15148"
DEER_CREEK_CITY = "15184"
DEER_RIVER_CITY = "15310"
DEERWOOD_CITY = "15346"
DELANO_CITY = "15454"
DELAVAN_CITY = "15472"
DELHI_CITY = "15544"
DELLWOOD_CITY = "15616"
DENHAM_CITY = "15670"
DENNISON_CITY = "15706"
DENT_CITY = "15724"
DETROIT_LAKES_CITY = "15832"
DEXTER_CITY = "15886"
DILWORTH_CITY = "15976"
DODGE_CENTER_CITY = "15994"
DONALDSON_CITY = "16030"
DONNELLY_CITY = "16084"
DORAN_CITY = "16156"
DOVER_CITY = "16264"
DOVRAY_CITY = "16300"
DRESBACH_CDP = "16390"
DULUTH_CITY = "17000"
DUMONT_CITY = "17090"
DUNDAS_CITY = "17126"
DUNDEE_CITY = "17144"
DUNNELL_CITY = "17180"
EAGAN_CITY = "17288"
EAGLE_BEND_CITY = "17342"
EAGLE_LAKE_CITY = "17378"
EAST_BETHEL_CITY = "17486"
EAST_GRAND_FORKS_CITY = "17612"
EAST_GULL_LAKE_CITY = "17630"
EASTON_CITY = "17738"
EBRO_CDP = "17882"
ECHO_CITY = "17900"
EDEN_PRAIRIE_CITY = "18116"
EDEN_VALLEY_CITY = "18134"
EDGERTON_CITY = "18152"
EDINA_CITY = "18188"
EFFIE_CITY = "18260"
EITZEN_CITY = "18368"
ELBA_CITY = "18386"
ELBOW_LAKE_CDP = "18440"
ELBOW_LAKE_CITY = "18458"
ELGIN_CITY = "18530"
ELIZABETH_CITY = "18566"
ELK_RIVER_CITY = "18674"
ELKO_NEW_MARKET_CITY = "18662"
ELKTON_CITY = "18728"
ELLENDALE_CITY = "18746"
ELLSWORTH_CITY = "18836"
ELMDALE_CITY = "18872"
ELMORE_CITY = "18998"
ELROSA_CITY = "19088"
ELY_CITY = "19142"
ELYSIAN_CITY = "19160"
EMILY_CITY = "19286"
EMMONS_CITY = "19340"
ERHARD_CITY = "19556"
ERSKINE_CITY = "19700"
ESKO_CDP = "19718"
ESSIG_CDP = "19754"
EVAN_CITY = "19880"
EVANSVILLE_CITY = "19898"
EVELETH_CITY = "19934"
EXCELSIOR_CITY = "20078"
EYOTA_CITY = "20114"
FAIRFAX_CITY = "20222"
FAIRHAVEN_CDP = "20276"
FAIRMONT_CITY = "20330"
FALCON_HEIGHTS_CITY = "20420"
FARIBAULT_CITY = "20546"
FARMINGTON_CITY = "20618"
FARWELL_CITY = "20690"
FEDERAL_DAM_CITY = "20798"
FELTON_CITY = "20834"
FERGUS_FALLS_CITY = "20906"
FERTILE_CITY = "20978"
FIFTY_LAKES_CITY = "21032"
FINLAND_CDP = "21104"
FINLAYSON_CITY = "21122"
FISH_LAKE_CDP = "21196"
FISHER_CITY = "21158"
FLENSBURG_CITY = "21266"
FLOODWOOD_CITY = "21338"
FLORENCE_CITY = "21410"
FOLEY_CITY = "21536"
FORADA_CITY = "21608"
FOREST_LAKE_CITY = "21770"
FORESTON_CITY = "21824"
FORT_RIPLEY_CITY = "21932"
FOSSTON_CITY = "21986"
FOUNTAIN_CITY = "22094"
FOXHOME_CITY = "22202"
FRANKLIN_CITY = "22364"
FRAZEE_CITY = "22472"
FREEBORN_CITY = "22526"
FREEPORT_CITY = "22652"
FRIDLEY_CITY = "22814"
FRONTENAC_CDP = "22904"
FROST_CITY = "22940"
FULDA_CITY = "22958"
FUNKLEY_CITY = "22976"
GARDEN_CITY_CDP = "23084"
GARFIELD_CITY = "23120"
GARRISON_CITY = "23192"
GARVIN_CITY = "23228"
GARY_CITY = "23246"
GAYLORD_CITY = "23300"
GEM_LAKE_CITY = "23318"
GENEVA_CITY = "23354"
GENOLA_CITY = "23444"
GEORGETOWN_CITY = "23498"
GHENT_CITY = "23660"
GIBBON_CITY = "23678"
GILBERT_CITY = "23714"
GILMAN_CITY = "23804"
GLENCOE_CITY = "23948"
GLENVILLE_CITY = "24056"
GLENWOOD_CITY = "24074"
GLYNDON_CITY = "24182"
GOLDEN_VALLEY_CITY = "24308"
GONVICK_CITY = "24344"
GOOD_THUNDER_CITY = "24506"
GOODHUE_CITY = "24398"
GOODLAND_CDP = "24434"
GOODRIDGE_CITY = "24470"
GOODVIEW_CITY = "24524"
GRACEVILLE_CITY = "24758"
GRANADA_CITY = "24884"
GRAND_MARAIS_CITY = "24992"
GRAND_MEADOW_CITY = "25010"
GRAND_RAPIDS_CITY = "25118"
GRANITE_FALLS_CITY = "25280"
GRANT_CITY = "25334"
GRASSTON_CITY = "25424"
GREEN_ISLE_CITY = "25658"
GREENBUSH_CITY = "25604"
GREENFIELD_CITY = "25622"
GREENWALD_CITY = "25874"
GREENWOOD_CITY = "25918"
GREY_EAGLE_CITY = "26000"
GROVE_CITY_CITY = "26126"
GRYGLA_CITY = "26216"
GULLY_CITY = "26270"
HACKENSACK_CITY = "26378"
HADLEY_CITY = "26450"
HALLOCK_CITY = "26576"
HALMA_CITY = "26612"
HALSTAD_CITY = "26630"
HAM_LAKE_CITY = "26738"
HAMBURG_CITY = "26666"
HAMMOND_CITY = "26828"
HAMPTON_CITY = "26864"
HANCOCK_CITY = "26936"
HANLEY_FALLS_CITY = "26972"
HANOVER_CITY = "26990"
HANSKA_CITY = "27008"
HARDING_CITY = "27098"
HARDWICK_CITY = "27116"
HARMONY_CITY = "27188"
HARRIS_CITY = "27278"
HARTLAND_CITY = "27404"
HASTINGS_CITY = "27530"
HATFIELD_CITY = "27566"
HAWLEY_CITY = "27746"
HAYFIELD_CITY = "27872"
HAYWARD_CITY = "27944"
HAZEL_RUN_CITY = "28016"
HECTOR_CITY = "28124"
HEIDELBERG_CITY = "28214"
HENDERSON_CITY = "28394"
HENDRICKS_CITY = "28430"
HENDRUM_CITY = "28484"
HENNING_CITY = "28520"
HENRIETTE_CITY = "28574"
HERMAN_CITY = "28646"
HERMANTOWN_CITY = "28682"
HERON_LAKE_CITY = "28700"
HEWITT_CITY = "28754"
HIBBING_CITY = "28790"
HIGH_FOREST_CDP = "28862"
HILL_CITY_CITY = "29096"
HILLMAN_CITY = "29150"
HILLS_CITY = "29204"
HILLTOP_CITY = "29258"
HINCKLEY_CITY = "29294"
HITTERDAL_CITY = "29402"
HOFFMAN_CITY = "29474"
HOKAH_CITY = "29510"
HOLDINGFORD_CITY = "29582"
HOLLAND_CITY = "29618"
HOLLANDALE_CITY = "29636"
HOLLOWAY_CITY = "29672"
HOLT_CITY = "29870"
HOMER_CDP = "30014"
HOPKINS_CITY = "30140"
HOUSTON_CITY = "30230"
HOWARD_LAKE_CITY = "30284"
HOYT_LAKES_CITY = "30302"
HUBBARD_CDP = "30320"
HUGO_CITY = "30392"
HUMBOLDT_CITY = "30446"
HUTCHINSON_CITY = "30644"
IHLEN_CITY = "30806"
INDEPENDENCE_CITY = "30842"
INGER_CDP = "30950"
INTERNATIONAL_FALLS_CITY = "31040"
INVER_GROVE_HEIGHTS_CITY = "31076"
IONA_CITY = "31094"
IRON_JUNCTION_CITY = "31238"
IRONTON_CITY = "31274"
ISANTI_CITY = "31328"
ISLE_CITY = "31472"
IVANHOE_CITY = "31526"
JACKSON_CITY = "31562"
JANESVILLE_CITY = "31706"
JASPER_CITY = "31760"
JEFFERS_CITY = "31796"
JENKINS_CITY = "31832"
JOHNSON_CITY = "32012"
JORDAN_CITY = "32174"
KANDIYOHI_CITY = "32372"
KARLSTAD_CITY = "32444"
KASOTA_CITY = "32462"
KASSON_CITY = "32498"
KEEWATIN_CITY = "32570"
KELLIHER_CITY = "32606"
KELLOGG_CITY = "32642"
KENNEDY_CITY = "32732"
KENNETH_CITY = "32750"
KENSINGTON_CITY = "32768"
KENT_CITY = "32786"
KENYON_CITY = "32840"
KERKHOVEN_CITY = "32876"
KERRICK_CITY = "32912"
KETTLE_RIVER_CITY = "32966"
KIESTER_CITY = "33056"
KILKENNY_CITY = "33110"
KIMBALL_CITY = "33164"
KINBRAE_CITY = "33236"
KINGSTON_CITY = "33344"
KINNEY_CITY = "33416"
KNIFE_RIVER_CDP = "33578"
LA_CRESCENT_CITY = "33866"
LA_PRAIRIE_CITY = "35648"
LA_SALLE_CITY = "35702"
LAFAYETTE_CITY = "33920"
LAKE_BENTON_CITY = "34100"
LAKE_BRONSON_CITY = "34136"
LAKE_CITY_CITY = "34172"
LAKE_CRYSTAL_CITY = "34190"
LAKE_ELMO_CITY = "34244"
LAKE_GEORGE_CDP = "34370"
LAKE_HENRY_CITY = "34478"
LAKE_LILLIAN_CITY = "34676"
LAKE_PARK_CITY = "34784"
LAKE_SHORE_CITY = "34928"
LAKE_ST_CROIX_BEACH_CITY = "34865"
LAKE_WILSON_CITY = "35198"
LAKEFIELD_CITY = "34316"
LAKELAND_SHORES_CITY = "34658"
LAKELAND_CITY = "34622"
LAKEVILLE_CITY = "35180"
LAMBERTON_CITY = "35288"
LANCASTER_CITY = "35378"
LANDFALL_CITY = "35414"
LANESBORO_CITY = "35450"
LANSING_CDP = "35558"
LAPORTE_CITY = "35612"
LASTRUP_CITY = "35720"
LAUDERDALE_CITY = "35738"
LE_CENTER_CITY = "36134"
LE_ROY_CITY = "36620"
LE_SUEUR_CITY = "36746"
LENGBY_CITY = "36404"
LEONARD_CITY = "36494"
LEONIDAS_CITY = "36530"
LEOTA_CDP = "36548"
LESTER_PRAIRIE_CITY = "36728"
LEWISTON_CITY = "36800"
LEWISVILLE_CITY = "36818"
LEXINGTON_CITY = "36836"
LILYDALE_CITY = "37016"
LINDSTROM_CITY = "37304"
LINO_LAKES_CITY = "37322"
LISMORE_CITY = "37412"
LITCHFIELD_CITY = "37448"
LITTLE_CANADA_CITY = "37502"
LITTLE_FALLS_CITY = "37556"
LITTLE_ROCK_CDP = "37656"
LITTLEFORK_CITY = "37592"
LONG_BEACH_CITY = "37970"
LONG_LAKE_CITY = "38006"
LONG_PRAIRIE_CITY = "38060"
LONGVILLE_CITY = "38114"
LONSDALE_CITY = "38150"
LORETTO_CITY = "38222"
LOUISBURG_CITY = "38258"
LOWRY_CITY = "38366"
LUCAN_CITY = "38420"
LUTSEN_CDP = "38546"
LUVERNE_CITY = "38564"
LYLE_CITY = "38654"
LYND_CITY = "38708"
MABEL_CITY = "38888"
MADELIA_CITY = "39230"
MADISON_LAKE_CITY = "39320"
MADISON_CITY = "39266"
MAGNOLIA_CITY = "39338"
MAHNOMEN_CDP = "39394"
MAHNOMEN_CITY = "39392"
MAHTOMEDI_CITY = "39428"
MAHTOWA_CDP = "39446"
MANCHESTER_CITY = "39716"
MANHATTAN_BEACH_CITY = "39806"
MANKATO_CITY = "39878"
MANTORVILLE_CITY = "39986"
MAPLE_GROVE_CITY = "40166"
MAPLE_LAKE_CITY = "40220"
MAPLE_PLAIN_CITY = "40256"
MAPLETON_CITY = "40310"
MAPLEVIEW_CITY = "40346"
MAPLEWOOD_CITY = "40382"
MARBLE_CITY = "40418"
MARIETTA_CITY = "40526"
MARINE_ON_ST_CROIX_CITY = "40562"
MARION_CDP = "40598"
MARSHALL_CITY = "40688"
MARTIN_LAKE_CDP = "40814"
MAYER_CITY = "41138"
MAYNARD_CITY = "41210"
MAZEPPA_CITY = "41282"
MCGRATH_CITY = "38996"
MCGREGOR_CITY = "39014"
MCINTOSH_CITY = "39050"
MCKINLEY_CITY = "39140"
MEADOWLANDS_CITY = "41372"
MEDFORD_CITY = "41426"
MEDICINE_LAKE_CITY = "41462"
MEDINA_CITY = "41480"
MEIRE_GROVE_CITY = "41534"
MELROSE_CITY = "41570"
MENAHGA_CITY = "41660"
MENDOTA_HEIGHTS_CITY = "41696"
MENDOTA_CITY = "41678"
MENTOR_CITY = "41714"
MERRIFIELD_CDP = "41804"
MIDDLE_RIVER_CITY = "41912"
MIDWAY_CDP = "42010"
MIESVILLE_CITY = "42092"
MILACA_CITY = "42110"
MILAN_CITY = "42146"
MILLERVILLE_CITY = "42254"
MILLVILLE_CITY = "42290"
MILROY_CITY = "42362"
MILTONA_CITY = "42398"
MINNEAPOLIS_CITY = "43000"
MINNEISKA_CITY = "43036"
MINNEOTA_CITY = "43126"
MINNESOTA_CITY_CITY = "43144"
MINNESOTA_LAKE_CITY = "43198"
MINNETONKA_BEACH_CITY = "43270"
MINNETONKA_CITY = "43252"
MINNETRISTA_CITY = "43306"
MIZPAH_CITY = "43540"
MONTEVIDEO_CITY = "43720"
MONTGOMERY_CITY = "43738"
MONTICELLO_CITY = "43774"
MONTROSE_CITY = "43810"
MOORHEAD_CITY = "43864"
MOOSE_LAKE_CITY = "43954"
MORA_CITY = "44044"
MORGAN_CITY = "44116"
MORRIS_CITY = "44242"
MORRISTOWN_CITY = "44296"
MORTON_CITY = "44368"
MOTLEY_CITY = "44422"
MOUND_CITY = "44476"
MOUNDS_VIEW_CITY = "44530"
MOUNTAIN_IRON_CITY = "44548"
MOUNTAIN_LAKE_CITY = "44566"
MURDOCK_CITY = "44818"
MYRTLE_CITY = "44890"
NASHUA_CITY = "44944"
NASHWAUK_CITY = "44980"
NASSAU_CITY = "45016"
NAYTAHWAUSH_CDP = "45052"
NELSON_CITY = "45106"
NERSTRAND_CITY = "45196"
NETT_LAKE_CDP = "45279"
NEVIS_CITY = "45340"
NEW_AUBURN_CITY = "45376"
NEW_BRIGHTON_CITY = "45430"
NEW_GERMANY_CITY = "45556"
NEW_HOPE_CITY = "45628"
NEW_LONDON_CITY = "45682"
NEW_MUNICH_CITY = "45772"
NEW_PRAGUE_CITY = "45808"
NEW_RICHLAND_CITY = "45862"
NEW_TRIER_CITY = "46024"
NEW_ULM_CITY = "46042"
NEW_YORK_MILLS_CITY = "46060"
NEWFOLDEN_CITY = "45520"
NEWPORT_CITY = "45790"
NICOLLET_CITY = "46150"
NIELSVILLE_CITY = "46258"
NIMROD_CITY = "46294"
NISSWA_CITY = "46348"
NORCROSS_CITY = "46492"
NORTH_BRANCH_CITY = "46798"
NORTH_MANKATO_CITY = "47068"
NORTH_OAKS_CITY = "47104"
NORTH_ST_PAUL_CITY = "47221"
NORTHFIELD_CITY = "46924"
NORTHOME_CITY = "47122"
NORTHROP_CITY = "47212"
NORWOOD_YOUNG_AMERICA_CITY = "47520"
NOWTHEN_CITY = "47536"
OAK_GROVE_CITY = "47690"
OAK_PARK_HEIGHTS_CITY = "47914"
OAKDALE_CITY = "47680"
ODESSA_CITY = "48058"
ODIN_CITY = "48094"
OGEMA_CITY = "48130"
OGILVIE_CITY = "48166"
OKABENA_CITY = "48184"
OKLEE_CITY = "48202"
OLIVIA_CITY = "48256"
ONAMIA_CITY = "48310"
ORMSBY_CITY = "48562"
ORONO_CITY = "48580"
ORONOCO_CITY = "48598"
ORR_CITY = "48634"
ORTONVILLE_CITY = "48706"
OSAGE_CDP = "48760"
OSAKIS_CITY = "48796"
OSLO_CITY = "48976"
OSSEO_CITY = "49012"
OSTRANDER_CITY = "49030"
OTSEGO_CITY = "49138"
OTTERTAIL_CITY = "49210"
OWATONNA_CITY = "49300"
PALISADE_CITY = "49498"
PARK_RAPIDS_CITY = "49768"
PARKERS_PRAIRIE_CITY = "49732"
PAYNESVILLE_CITY = "49966"
PEASE_CITY = "50056"
PELICAN_RAPIDS_CITY = "50164"
PEMBERTON_CITY = "50200"
PENNOCK_CITY = "50344"
PEQUOT_LAKES_CITY = "50416"
PERHAM_CITY = "50470"
PERLEY_CITY = "50506"
PETERSON_CITY = "50596"
PICKWICK_CDP = "50740"
PIERZ_CITY = "50776"
PILLAGER_CITY = "50902"
PINE_BEND_CDP = "51028"
PINE_CITY_CITY = "51064"
PINE_ISLAND_CITY = "51136"
PINE_POINT_CDP = "51234"
PINE_RIVER_CITY = "51280"
PINE_SPRINGS_CITY = "51316"
PIPESTONE_CITY = "51388"
PLAINVIEW_CITY = "51424"
PLATO_CITY = "51460"
PLUMMER_CITY = "51712"
PLYMOUTH_CITY = "51730"
PONEMAH_CDP = "51892"
PORTER_CITY = "52144"
PRESTON_CITY = "52450"
PRINCETON_CITY = "52522"
PRINSBURG_CITY = "52558"
PRIOR_LAKE_CITY = "52594"
PROCTOR_CITY = "52630"
QUAMBA_CITY = "52756"
RACINE_CITY = "52882"
RAMSEY_CITY = "53026"
RANDALL_CITY = "53080"
RANDOLPH_CITY = "53098"
RANIER_CITY = "53134"
RAYMOND_CITY = "53296"
RED_LAKE_CDP = "53458"
RED_LAKE_FALLS_CITY = "53476"
RED_WING_CITY = "53620"
REDBY_CDP = "53386"
REDWOOD_FALLS_CITY = "53656"
REGAL_CITY = "53710"
REMER_CITY = "53782"
RENVILLE_CITY = "53890"
REVERE_CITY = "53908"
RICE_LAKE_CDP = "54056"
RICE_LAKE_CITY = "54060"
RICE_CITY = "53998"
RICHFIELD_CITY = "54214"
RICHMOND_CITY = "54268"
RICHVILLE_CITY = "54340"
RIVERLAND_CDP = "54596"
RIVERTON_CITY = "54736"
ROBBINSDALE_CITY = "54808"
ROCHESTER_CITY = "54880"
ROCK_CREEK_CITY = "54934"
ROCKFORD_CITY = "55006"
ROCKVILLE_CITY = "55078"
ROGERS_CITY = "55186"
ROLLINGSTONE_CITY = "55276"
RONNEBY_CDP = "55366"
ROOSEVELT_CITY = "55438"
ROSCOE_CITY = "55510"
ROSE_CREEK_CITY = "55600"
ROSEAU_CITY = "55546"
ROSEMOUNT_CITY = "55726"
ROSEVILLE_CITY = "55852"
ROTHSAY_CITY = "56014"
ROUND_LAKE_CITY = "56086"
ROY_LAKE_CDP = "56212"
ROYALTON_CITY = "56176"
RUSH_CITY_CITY = "56266"
RUSHFORD_VILLAGE_CITY = "56302"
RUSHFORD_CITY = "56284"
RUSHMORE_CITY = "56338"
RUSSELL_CITY = "56428"
RUTHTON_CITY = "56482"
RUTLEDGE_CITY = "56518"
SABIN_CITY = "56554"
SACRED_HEART_CITY = "56572"
SANBORN_CITY = "58306"
SANDSTONE_CITY = "58396"
SARGEANT_CITY = "58576"
SARTELL_CITY = "58612"
SAUK_CENTRE_CITY = "58648"
SAUK_RAPIDS_CITY = "58684"
SAVAGE_CITY = "58738"
SCANDIA_CITY = "58900"
SCANLON_CITY = "58936"
SEAFORTH_CITY = "59098"
SEARLES_CDP = "59116"
SEBEKA_CITY = "59152"
SEDAN_CITY = "59188"
SHAFER_CITY = "59314"
SHAKOPEE_CITY = "59350"
SHELLY_CITY = "59566"
SHERBURN_CITY = "59620"
SHEVLIN_CITY = "59782"
SHOREVIEW_CITY = "59998"
SHOREWOOD_CITY = "60016"
SILVER_BAY_CITY = "60250"
SILVER_CREEK_CDP = "60322"
SILVER_LAKE_CITY = "60376"
SKYLINE_CITY = "60754"
SLAYTON_CITY = "60808"
SLEEPY_EYE_CITY = "60844"
SOBIESKI_CITY = "61006"
SOLWAY_CITY = "61114"
SOUDAN_CDP = "61204"
SOUTH_END_CDP = "61340"
SOUTH_HAVEN_CITY = "61402"
SOUTH_ST_PAUL_CITY = "61492"
SPICER_CITY = "61690"
SPRING_GROVE_CITY = "61852"
SPRING_HILL_CITY = "61888"
SPRING_LAKE_PARK_CITY = "61996"
SPRING_PARK_CITY = "62014"
SPRING_VALLEY_CITY = "62104"
SPRINGFIELD_CITY = "61816"
SQUAW_LAKE_CITY = "62284"
ST_ANTHONY_CITY_HENNEPIN_AND_RAMSEY_COUNTIES = "56680"
ST_ANTHONY_CITY_STEARNS_COUNTY = "56698"
ST_AUGUSTA_CITY = "56724"
ST_BONIFACIUS_CITY = "56770"
ST_CHARLES_CITY = "56788"
ST_CLAIR_CITY = "56824"
ST_CLOUD_CITY = "56896"
ST_FRANCIS_CITY = "56950"
ST_HILAIRE_CITY = "57022"
ST_JAMES_CITY = "57040"
ST_JOHNS_UNIVERSITY_CDP = "57094"
ST_JOSEPH_CITY = "57130"
ST_LEO_CITY = "57202"
ST_LOUIS_PARK_CITY = "57220"
ST_MARTIN_CITY = "57238"
ST_MARYS_POINT_CITY = "57292"
ST_MICHAEL_CITY = "57346"
ST_PAUL_PARK_CITY = "58018"
ST_PAUL_CITY = "58000"
ST_PETER_CITY = "58036"
ST_ROSA_CITY = "58072"
ST_STEPHEN_CITY = "58090"
ST_VINCENT_CITY = "58144"
STACY_CITY = "62320"
STANCHFIELD_CDP = "62356"
STAPLES_CITY = "62446"
STARBUCK_CITY = "62500"
STEEN_CITY = "62662"
STEPHEN_CITY = "62698"
STEWART_CITY = "62788"
STEWARTVILLE_CITY = "62806"
STILLWATER_CITY = "62824"
STOCKTON_CITY = "62896"
STORDEN_CITY = "63022"
STRANDQUIST_CITY = "63112"
STRATHCONA_CITY = "63130"
STURGEON_LAKE_CITY = "63220"
SUNBURG_CITY = "63454"
SUNFISH_LAKE_CITY = "63544"
SWANVILLE_CITY = "63778"
TACONITE_CITY = "64048"
TAMARACK_CITY = "64156"
TAOPI_CITY = "64210"
TAUNTON_CITY = "64264"
TAYLORS_FALLS_CITY = "64318"
TENSTRIKE_CITY = "64444"
THE_LAKES_CDP = "64543"
THE_RANCH_CDP = "64547"
THIEF_RIVER_FALLS_CITY = "64570"
TINTAH_CITY = "64948"
TONKA_BAY_CITY = "65164"
TOWER_CITY = "65272"
TRACY_CITY = "65308"
TRAIL_CITY = "65344"
TRIMONT_CITY = "65470"
TROMMALD_CITY = "65506"
TROSKY_CITY = "65542"
TRUMAN_CITY = "65668"
TURTLE_RIVER_CITY = "65794"
TWIN_LAKES_CDP = "65927"
TWIN_LAKES_CITY = "65920"
TWIN_VALLEY_CITY = "65938"
TWO_HARBORS_CITY = "65956"
TYLER_CITY = "66046"
ULEN_CITY = "66136"
UNDERWOOD_CITY = "66172"
UPSALA_CITY = "66334"
URBANK_CITY = "66388"
UTICA_CITY = "66424"
VADNAIS_HEIGHTS_CITY = "66460"
VERGAS_CITY = "66766"
VERMILLION_CITY = "66802"
VERNDALE_CITY = "66874"
VERNON_CENTER_CITY = "66910"
VESTA_CITY = "66982"
VICTORIA_CITY = "67036"
VIKING_CITY = "67090"
VILLARD_CITY = "67144"
VINELAND_CDP = "67180"
VINING_CITY = "67216"
VIRGINIA_CITY = "67288"
WABASHA_CITY = "67378"
WABASSO_CITY = "67396"
WACONIA_CITY = "67432"
WADENA_CITY = "67504"
WAHKON_CITY = "67558"
WAITE_PARK_CITY = "67612"
WALDORF_CITY = "67756"
WALKER_CITY = "67792"
WALNUT_GROVE_CITY = "67846"
WALTERS_CITY = "67900"
WALTHAM_CITY = "67918"
WANAMINGO_CITY = "67972"
WANDA_CITY = "68008"
WARBA_CITY = "68080"
WARREN_CITY = "68170"
WARROAD_CITY = "68224"
WARSAW_CDP = "68260"
WASECA_CITY = "68296"
WATERTOWN_CITY = "68548"
WATERVILLE_CITY = "68584"
WATKINS_CITY = "68620"
WATSON_CITY = "68656"
WAUBUN_CITY = "68674"
WAVERLY_CITY = "68764"
WAYZATA_CITY = "68818"
WELCOME_CITY = "69070"
WELLS_CITY = "69106"
WENDELL_CITY = "69142"
WEST_CONCORD_CITY = "69304"
WEST_ROY_LAKE_CDP = "69690"
WEST_ST_PAUL_CITY = "69700"
WEST_UNION_CITY = "69736"
WESTBROOK_CITY = "69250"
WESTPORT_CITY = "69628"
WHALAN_CITY = "69808"
WHEATON_CITY = "69844"
WHIPHOLT_CDP = "69880"
WHITE_BEAR_LAKE_CITY = "69970"
WHITE_EARTH_CDP = "70006"
WILDER_CITY = "70258"
WILLERNIE_CITY = "70366"
WILLIAMS_CITY = "70402"
WILLMAR_CITY = "70420"
WILLOW_RIVER_CITY = "70492"
WILMONT_CITY = "70582"
WILTON_CITY = "70708"
WINDOM_CITY = "70798"
WINGER_CITY = "70870"
WINNEBAGO_CITY = "70924"
WINONA_CITY = "71032"
WINSTED_CITY = "71086"
WINTHROP_CITY = "71122"
WINTON_CITY = "71140"
WOLF_LAKE_CITY = "71338"
WOLVERTON_CITY = "71392"
WOOD_LAKE_CITY = "71446"
WOODBURY_CITY = "71428"
WOODLAND_CITY = "71500"
WOODSTOCK_CITY = "71680"
WORTHINGTON_CITY = "71734"
WRENSHALL_CITY = "71788"
WRIGHT_CITY = "71824"
WYKOFF_CITY = "71950"
WYOMING_CITY = "72022"
ZEMPLE_CITY = "72184"
ZIMMERMAN_CITY = "72238"
ZUMBRO_FALLS_CITY = "72310"
ZUMBROTA_CITY = "72328"
